@@ -2,6 +2,7 @@
 #define VIEWER_H
 
 #include "Viewer_config.h"
+#include <CGAL_demo/Viewer_interface.h>
 
 #include <QGLViewer/qglviewer.h>
 #include <QPoint>
@@ -14,7 +15,7 @@ class QKeyEvent;
 
 class Viewer_impl;
 
-class VIEWER_EXPORT Viewer : public QGLViewer {
+class VIEWER_EXPORT Viewer : public Viewer_interface {
 
   Q_OBJECT
 
@@ -24,6 +25,7 @@ public:
 
   // overload several QGLViewer virtual functions
   void draw();
+  void fastDraw();
   void initializeGL();
   void drawWithNames();
   void postSelection(const QPoint&);
@@ -31,15 +33,7 @@ public:
   void setScene(Scene_draw_interface* scene);
   bool antiAliasing() const;
 
-  static bool readFrame(QString, qglviewer::Frame&);
-  static QString dumpFrame(const qglviewer::Frame&);
-
-signals:
-  void selected(int);
-  void requestContextMenu(QPoint global_pos);
-  void selectedPoint(double, double, double);
-  void selectionRay(double, double, double, double, double, double);
-
+  bool inFastDrawing() const;
 public slots:
   void setAntiAliasing(bool b);
   void setTwoSides(bool b);
