@@ -20,8 +20,8 @@ int main()
     }
   
   // 2) Create two tetrahedra.
-  Dart_handle dh1 = make_combinatorial_tetrahedron(cm);  
-  Dart_handle dh2 = make_combinatorial_tetrahedron(cm);
+  Dart_handle dh1 = CGAL::make_combinatorial_tetrahedron(cm);  
+  Dart_handle dh2 = CGAL::make_combinatorial_tetrahedron(cm);
 
   // 3) 3-sew them.
   cm.sew<3>(dh1, dh2);
