@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Algebraic_curve_kernel_2.h $
-// $Id: Algebraic_curve_kernel_2.h 67093 2012-01-13 11:22:39Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Eric Berberich <eric@mpi-inf.mpg.de>
@@ -824,7 +824,7 @@ public:
       
     public:
 
-      typedef CGAL::cpp0x::array<Bound,4> result_type;
+      typedef CGAL::cpp11::array<Bound,4> result_type;
 
       Isolate_2(const Algebraic_kernel_d_2* kernel) 
 	: _m_kernel(kernel) {}
