@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Algebraic_foundations/include/CGAL/Algebraic_structure_traits.h $
-// $Id: Algebraic_structure_traits.h 67093 2012-01-13 11:22:39Z lrineau $
+// $URL$
+// $Id$
 //
 //
 // Author(s)     : Michael Hemmer    <hemmer@mpi-inf.mpg.de>
@@ -24,8 +24,12 @@
 #ifndef CGAL_ALGEBRAIC_STRUCTURE_TRAITS_H
 #define CGAL_ALGEBRAIC_STRUCTURE_TRAITS_H
 
-#include <CGAL/number_type_basic.h>
+#include <functional>
+#include <CGAL/tags.h>
 #include <CGAL/type_traits.h>
+#include <CGAL/Coercion_traits.h>
+#include <CGAL/assertions.h>
+#include <CGAL/use.h>
 
 namespace CGAL {
 
@@ -260,6 +264,7 @@ class Algebraic_structure_traits_base< Type_,
                 const Type& y) const { 
             typedef Algebraic_structure_traits<Type> AST; 
             typedef typename AST::Is_exact Is_exact;
+            CGAL_USE_TYPE(Is_exact);
             typename AST::Div actual_div;
             
             CGAL_precondition_msg( 
@@ -355,6 +360,7 @@ class Algebraic_structure_traits_base< Type_,
                 Type& r ) const {
             typedef Coercion_traits< NT1, NT2 > CT;
             typedef typename CT::Type Type; 
+            CGAL_USE_TYPE(Type);
             CGAL_static_assertion(( 
               ::boost::is_same<Type , Type >::value));
             
@@ -456,6 +462,7 @@ class Algebraic_structure_traits_base< Type_, Field_tag >
                                         const Type& y) const { 
             typedef Algebraic_structure_traits<Type> AST; 
             typedef typename AST::Is_exact Is_exact;
+            CGAL_USE_TYPE(Is_exact);
 	    CGAL_precondition_code( bool ie = Is_exact::value; )
             CGAL_precondition_msg( !ie || (x / y) * y  == x,
                     "'x' must be divisible by 'y' in "
@@ -482,13 +489,13 @@ class Algebraic_structure_traits_base< Type_, Field_tag >
     : public std::binary_function< Type, Type, bool > { 
   public:
     bool operator()( const Type& CGAL_precondition_code(x), const Type& /* y */) const {
-      typedef Algebraic_structure_traits<Type> AST;
+      CGAL_precondition_code( typedef Algebraic_structure_traits<Type> AST);
       CGAL_precondition( typename AST::Is_zero()(x) == false );
       return true;
     } 
     // second operator computing q
     bool operator()( const Type& x, const Type& y, Type& q) const {
-      typedef Algebraic_structure_traits<Type> AST;
+      CGAL_precondition_code(typedef Algebraic_structure_traits<Type> AST);
       CGAL_precondition( typename AST::Is_zero()(x) == false );
       q = y/x;
       return true;
