@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Alpha_shapes_2/include/CGAL/Alpha_shape_2.h $
-// $Id: Alpha_shape_2.h 67216 2012-01-17 15:28:40Z sloriot $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Tran Kai Frank DA
@@ -591,7 +591,7 @@ public:
       // Classifies a point `p' with respect to `A'.
       Locate_type type;
       int i;
-      Face_handle pFace = locate(p, type, i);
+      Face_handle pFace = this->locate(p, type, i);
       switch (type) 
 	{
 	case VERTEX            : return classify(pFace->vertex(i), alpha);
@@ -680,7 +680,7 @@ public:
     }
 
   size_type 
-  number_solid_components(const Type_of_alpha& alpha) const
+  number_solid_components(const Type_of_alpha& /* alpha */) const
     {
       return number_of_solid_components(get_alpha());
     }
