@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Apollonius_graph_2/include/CGAL/Apollonius_graph_2/Apollonius_graph_2_impl.h $
-// $Id: Apollonius_graph_2_impl.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
@@ -22,6 +22,8 @@
 #ifndef CGAL_APOLLONIUS_GRAPH_2_IMPL_H
 #define CGAL_APOLLONIUS_GRAPH_2_IMPL_H
 
+#include <CGAL/use.h>
+
 // class implementation continued
 //=================================
 
@@ -244,7 +246,7 @@ primal(const Edge e) const
 {
   typedef typename Geom_traits::Segment_2  Segment;
   typedef typename Geom_traits::Ray_2      Ray;
-  typedef CGAL::Hyperbola_segment_2<Gt>    Hyperbola_segment;
+  // typedef CGAL::Hyperbola_segment_2<Gt>    Hyperbola_segment;
   typedef CGAL::Parabola_segment_2<Gt>     Parabola_segment;
   //  typedef typename Geom_traits::Hyperbola_segment_2  Hyperbola_segment;
   //  typedef typename Geom_traits::Parabola_segment_2   Parabola_segment;
@@ -860,7 +862,7 @@ add_bogus_vertex(Edge e, List& l)
 {
   Edge esym = sym_edge(e);
   Face_handle g1 = e.first;
-  Face_handle g2 = esym.first;
+  CGAL_assertion_code(Face_handle g2 = esym.first);
 
   Vertex_handle v = insert_degree_2(e);
   Face_circulator fc(v);
@@ -1103,7 +1105,7 @@ retriangulate_conflict_region(const Site_2& p,	List& l,
   Edge e_start = l.front();
   Edge eit = e_start;
   do {
-    Edge esym = sym_edge(eit);
+    CGAL_assertion_code(Edge esym =)sym_edge(eit);
     Face_handle f = eit.first;
     int k = eit.second;
     CGAL_assertion( !l.is_in_list(esym) );
@@ -1824,6 +1826,7 @@ remove_degree_d_vertex(Vertex_handle v)
     } while ( ec != ec_start );
 
     CGAL_assertion( found );
+    CGAL_USE(found);
   }
   CGAL_triangulation_precondition( degree(v) == 3 );
 
