@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arrangement_on_surface_2_global.h $
-// $Id: Arrangement_on_surface_2_global.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -40,6 +40,8 @@
 #include <CGAL/Arrangement_2/Arr_traits_adaptor_2.h>
 #include <CGAL/Sweep_line_2/Sweep_line_2_utils.h>
 #include <CGAL/Sweep_line_2/Sweep_line_2_visitors.h>
+#include <CGAL/assertions.h>
+#include <CGAL/use.h>
 
 #include <boost/type_traits.hpp>
 
@@ -214,7 +216,6 @@ void insert (Arrangement_on_surface_2<GeomTraits, TopTraits>& arr,
              const Curve& c, const PointLocation& pl,
 	     typename PointLocation::Point_2*)
 {
-  typedef Arrangement_on_surface_2<GeomTraits, TopTraits>  Arr;
   typedef typename TopTraits::Zone_insertion_visitor       Zone_visitor;
   
   Zone_visitor visitor;
@@ -615,6 +616,7 @@ insert_non_intersecting_curve
                                                          Traits_adaptor_2;
   typedef typename Arr::Vertex_const_handle              Vertex_const_handle;
   typedef typename Arr::Halfedge_const_handle            Halfedge_const_handle;
+  CGAL_USE_TYPE(Halfedge_const_handle);
 
   const Traits_adaptor_2 * geom_traits =
     static_cast<const Traits_adaptor_2*> (arr.geometry_traits());
@@ -1184,7 +1186,6 @@ bool is_valid (const Arrangement_on_surface_2<GeomTraits, TopTraits>& arr)
 
   typedef Arrangement_on_surface_2<GeomTraits, TopTraits>   Arr;
   typedef GeomTraits                                        Geometry_traits_2;
-  typedef typename Geometry_traits_2::Point_2               Point_2;
   typedef typename Geometry_traits_2::X_monotone_curve_2    X_monotone_curve_2;
   
   // Define the sweep-line types:
@@ -1200,8 +1201,6 @@ bool is_valid (const Arrangement_on_surface_2<GeomTraits, TopTraits>& arr)
   typedef typename Arr::Vertex_const_handle           Vertex_const_handle;
   typedef typename Arr::Isolated_vertex_const_iterator
                                        Isolated_vertex_const_iterator;
-  typedef typename Arr::Ccb_halfedge_const_circulator 
-                                       Ccb_halfedge_const_circulator;
   typedef typename Arr::Halfedge_around_vertex_const_circulator 
                                        Halfedge_around_vertex_const_circulator;
   
@@ -1454,9 +1453,6 @@ OutputIterator zone (Arrangement_on_surface_2<GeomTraits, TopTraits>& arr,
                      const typename GeomTraits::X_monotone_curve_2& c,
                      OutputIterator oi)
 {
-  typedef Arrangement_on_surface_2<GeomTraits, TopTraits>
-    Arrangement_on_surface_2;
-
   // Create a default point-location object and use it to insert the curve.
   typename TopTraits::Default_point_location_strategy    def_pl (arr);
 
@@ -1585,9 +1581,6 @@ template <class GeomTraits, class TopTraits, class Curve>
 bool do_intersect (Arrangement_on_surface_2<GeomTraits, TopTraits>& arr, 
                    const Curve& c)
 {
-  typedef Arrangement_on_surface_2<GeomTraits, TopTraits>
-    Arrangement_on_surface_2;
-
   // Create a default point-location object and use it to insert the curve.
   typename TopTraits::Default_point_location_strategy    def_pl (arr);
   
