@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Circular_kernel_2/include/CGAL/Circular_kernel_2/Circular_arc_2.h $
-// $Id: Circular_arc_2.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Pedro Machado
 
@@ -41,6 +41,7 @@
 #endif
 
 #include <CGAL/intersections.h>
+#include <CGAL/result_of.h>
 
 namespace CGAL {
 namespace internal {
@@ -634,12 +635,14 @@ public:
        return _support;
     }
 
-    const Point_2 & center() const           
+    typename cpp11::result_of<typename CK::Construct_center_2(Circle_2)>::type
+    center() const           
     {
        return supporting_circle().center();
     }
 
-    const FT & squared_radius() const           
+    typename cpp11::result_of<typename CK::Compute_squared_radius_2(Circle_2)>::type
+    squared_radius() const           
     {
        return supporting_circle().squared_radius();
     }
