@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Circular_kernel_2/include/CGAL/Circular_kernel_2/function_objects_polynomial_circular.h $
-// $Id: function_objects_polynomial_circular.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Pedro Machado
 
@@ -619,7 +619,20 @@ namespace CircularFunctors {
   {
     public:
 
-    typedef void result_type;
+    template<typename>
+    struct result;
+
+    template<typename F>
+    struct result<F(typename CK::Line_2)>
+    {
+      typedef typename CK::Polynomial_1_2 type;
+    };
+
+    template<typename F>
+    struct result<F(typename CK::Circle_2)>
+    {
+      typedef typename CK::Polynomial_for_circles_2_2 type;
+    };
 
     typename CK::Polynomial_1_2
     operator() ( const typename CK::Line_2 & l )
@@ -830,17 +843,15 @@ namespace CircularFunctors {
 
 
   template <class CK>
-  class Compute_circular_x_2: Has_qrt
+  class Compute_circular_x_2
   {
     typedef typename CK::Circular_arc_point_2   Circular_arc_point_2;
     typedef typename CK::Root_of_2                 Root_of_2;
 
   public:
+    typedef const Root_of_2&            result_type;
 
-    typedef Root_of_2            result_type;
-    typedef const result_type &  qualified_result_type;
-
-    qualified_result_type operator() (const Circular_arc_point_2 & a) const
+    result_type operator() (const Circular_arc_point_2 & a) const
     {
       return (a.rep().x());
     }
@@ -848,17 +859,16 @@ namespace CircularFunctors {
 
 
   template <class CK>
-  class Compute_circular_y_2: Has_qrt
-	{
+  class Compute_circular_y_2
+  {
     typedef typename CK::Circular_arc_point_2   Circular_arc_point_2;
     typedef typename CK::Root_of_2                 Root_of_2;
 
   public:
 
-    typedef Root_of_2            result_type;
-    typedef const result_type &  qualified_result_type;
+    typedef const Root_of_2&            result_type;
     
-    qualified_result_type operator() (const Circular_arc_point_2 & a) const
+    result_type operator() (const Circular_arc_point_2 & a) const
     {
       return (a.rep().y());
     }
@@ -866,27 +876,21 @@ namespace CircularFunctors {
 
 
   template <class CK>
-  class Construct_circular_min_vertex_2 : Has_qrt
+  class Construct_circular_min_vertex_2
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
     typedef typename CK::Circular_arc_point_2      Circular_arc_point_2;
 
   public:
+    typedef const Circular_arc_point_2 &  result_type;
 
-    typedef Circular_arc_point_2 result_type;
-    typedef const result_type &  qualified_result_type;
-
-    qualified_result_type operator() (const Circular_arc_2 & a) const
+    result_type operator() (const Circular_arc_2 & a) const
     {
-//       if (a.rep().Cache_minmax == 't')
-// 	return (a.rep().source());
-//       if (a.rep().Cache_minmax == 's')
-// 	return (a.rep().target());
       return (a.rep().left());
     }
 
-    qualified_result_type operator() (const Line_arc_2 & a) const
+    result_type operator() (const Line_arc_2 & a) const
     {
       return (a.rep().left());
     }
@@ -894,7 +898,7 @@ namespace CircularFunctors {
   };
 
   template <class CK>
-  class Construct_circular_max_vertex_2: Has_qrt
+  class Construct_circular_max_vertex_2
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
@@ -902,19 +906,14 @@ namespace CircularFunctors {
 
   public:
 
-    typedef Circular_arc_point_2 result_type;
-    typedef const result_type &  qualified_result_type;
+    typedef const Circular_arc_point_2& result_type;
     
-    qualified_result_type operator() (const Circular_arc_2 & a) const
+    result_type operator() (const Circular_arc_2 & a) const
     {
-//       if (a.rep().Cache_minmax == 's')
-// 	return (a.rep().source());
-//       if (a.rep().Cache_minmax == 't')
-// 	return (a.rep().target());
       return (a.rep().right());
     }
 
-    qualified_result_type operator() (const Line_arc_2 & a) const
+    result_type operator() (const Line_arc_2 & a) const
     {
       return (a.rep().right());
     }
@@ -922,7 +921,7 @@ namespace CircularFunctors {
   };
 
   template <class CK>
-  class Construct_circular_source_vertex_2: Has_qrt
+  class Construct_circular_source_vertex_2
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
@@ -930,20 +929,19 @@ namespace CircularFunctors {
 
   public:
 
-    typedef Circular_arc_point_2 result_type;
-    typedef const result_type &  qualified_result_type;
+    typedef const Circular_arc_point_2& result_type;
     
-    qualified_result_type operator() (const Circular_arc_2 & a) const
+    result_type operator() (const Circular_arc_2 & a) const
     { return a.rep().source(); }
 
-    qualified_result_type operator() (const Line_arc_2 & a) const
+    result_type operator() (const Line_arc_2 & a) const
     { return a.rep().source();}
 
   };
 
 
   template <class CK>
-  class Construct_circular_target_vertex_2: Has_qrt
+  class Construct_circular_target_vertex_2
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
@@ -951,13 +949,12 @@ namespace CircularFunctors {
 
   public:
 
-    typedef Circular_arc_point_2 result_type;
-    typedef const result_type &  qualified_result_type;
+    typedef const Circular_arc_point_2& result_type;
    
-    qualified_result_type operator() (const Circular_arc_2 & a) const
+    result_type operator() (const Circular_arc_2 & a) const
     { return a.rep().target();}
 
-    qualified_result_type operator() (const Line_arc_2 & a) const
+    result_type operator() (const Line_arc_2 & a) const
     { return a.rep().target();}
 
   };
@@ -1195,7 +1192,7 @@ namespace CircularFunctors {
 
 #ifndef CGAL_NO_DEPRECATED_CODE
   template <class CK>
-  class Construct_supporting_circle_2: Has_qrt
+  class Construct_supporting_circle_2
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Circle_2                  Circle_2;
@@ -1212,7 +1209,7 @@ namespace CircularFunctors {
   
   
   template <class CK>
-  class Construct_supporting_line_2: Has_qrt
+  class Construct_supporting_line_2
   {
     typedef typename CK::Line_arc_2            Line_arc_2;
     typedef typename CK::Line_2                Line_2;
@@ -1233,32 +1230,27 @@ namespace CircularFunctors {
   class Construct_center_2
 	#ifndef CGAL_CFG_MATCHING_BUG_6
 	    : public CK::Linear_kernel::Construct_center_2
-         #else
-  : public  Has_qrt
 	#endif
   {
     typedef typename CK::Circular_arc_2  Circular_arc_2;
-	  public:
-
-		#ifndef CGAL_CFG_MATCHING_BUG_6
-			typedef typename CK::Linear_kernel::Construct_center_2::result_type result_type; 
-	    using CK::Linear_kernel::Construct_center_2::operator();
-		#else
+  public:
+    typedef typename CK::Linear_kernel::Construct_center_2::result_type result_type; 
+#ifndef CGAL_CFG_MATCHING_BUG_6
+    using CK::Linear_kernel::Construct_center_2::operator();
+#else
 
     typedef typename CK::Linear_kernel LK;
     typedef typename LK::Construct_center_2 LK_Construct_center_2;
-	  typedef typename CK::Point_2     Point_2;
-	  typedef typename CK::Circle_2    Circle_2;
-	public:
-    typedef Point_2          result_type;
+    typedef typename CK::Point_2     Point_2;
+    typedef typename CK::Circle_2    Circle_2;
 
-	  const result_type&
-	  operator()( const Circle_2& c) const
-	  { return LK_Construct_center_2()(c); }
-
-	#endif
-
-    const result_type&
+  public:
+    result_type
+    operator()( const Circle_2& c) const
+      { return LK_Construct_center_2()(c); }
+    
+#endif
+    result_type
     operator()(const Circular_arc_2& c) const
     { return c.rep().center(); }
 
@@ -1266,75 +1258,51 @@ namespace CircularFunctors {
 
   template <typename CK>
   class Compute_squared_radius_2
-#ifndef CGAL_CFG_MATCHING_BUG_6
-    : public CK::Linear_kernel::Compute_squared_radius_2
-#endif
   {
+
+  private:
     typedef typename CK::Circular_arc_2  Circular_arc_2;
-  public:
-
-#ifndef CGAL_CFG_MATCHING_BUG_6
-    typedef typename CK::Linear_kernel::Compute_squared_radius_2::result_type result_type; 
-    using CK::Linear_kernel::Compute_squared_radius_2::operator();
-#else
-
     typedef typename CK::Linear_kernel LK;
     typedef typename LK::Compute_squared_radius_2 LK_Compute_squared_radius_2;
     typedef typename CK::FT          FT;
     typedef typename CK::Point_2     Point_2;
     typedef typename CK::Circle_2    Circle_2;
   public:
-    typedef FT               result_type;
+    template<typename>
+    struct result{
+      typedef FT type;
+    };
+
+    template<typename F>
+    struct result<F(Circular_arc_2)> {
+      typedef typename cpp11::result_of<LK_Compute_squared_radius_2(Circle_2)>::type type;
+    };
+
+    template<typename F>
+    struct result<F(Circle_2)> {
+      typedef typename cpp11::result_of<LK_Compute_squared_radius_2(Circle_2)>::type type;
+    };
     
-    const result_type&
+    typename cpp11::result_of<LK_Compute_squared_radius_2(Circle_2)>::type
     operator()( const Circle_2& c) const
     { return LK_Compute_squared_radius_2()(c); }
     
-    result_type
-    operator()( const Point_2& p) const
+    FT operator()( const Point_2& p) const
     { return LK_Compute_squared_radius_2()(p); }
     
-    result_type
-    operator()( const Point_2& p, const Point_2& q) const
+    FT operator()( const Point_2& p, const Point_2& q) const
     { return LK_Compute_squared_radius_2()(p, q); }
     
-    result_type
-    operator()( const Point_2& p, const Point_2& q, const Point_2& r) const
+    FT operator()( const Point_2& p, const Point_2& q, const Point_2& r) const
     { return LK_Compute_squared_radius_2()(p, q, r); }
     
-#endif
-
-    const result_type&
+    typename cpp11::result_of<LK_Compute_squared_radius_2(Circle_2)>::type
     operator()(const Circular_arc_2& c) const
     { return c.rep().squared_radius(); }
 
   };
 
 } // namespace CircularFunctors
-
-#ifndef CGAL_CFG_DONT_OVERLOAD_TOO_MUCH
-  template < typename K>
-  struct Qualified_result_of<CircularFunctors::Construct_center_2<K>,
-                           typename K::Circular_arc_2>
-  {
-    typedef typename K::Point_2 const &   type;
-  };
-
-  template < typename K>
-  struct Qualified_result_of<CircularFunctors::Compute_squared_radius_2<K>,
-                           typename K::Circular_arc_2>
-  {
-    typedef typename K::FT const &   type;
-  };
-
-  template < typename K>
-  struct Qualified_result_of<CircularFunctors::Compute_squared_radius_2<K>,
-                           typename K::Circle_2>
-  {
-    typedef typename K::FT const &   type;
-  };
-#endif
-
 } // namespace CGAL
 
 #endif // CGAL_CIRCULAR_KERNEL_FUNCTION_OBJECTS_POLYNOMIAL_CIRCULAR_H
