@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Circular_kernel_2/include/CGAL/Circular_kernel_2/internal_functions_on_circular_arc_2.h $
-// $Id: internal_functions_on_circular_arc_2.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Pedro Machado
 
@@ -227,11 +227,11 @@ namespace CircularFunctors {
     //CGAL_kernel_precondition (A1.is_x_monotone());
     //CGAL_kernel_precondition (A2.is_x_monotone());
 
+#ifdef CGAL_INTERSECTION_MAP_FOR_XMONOTONIC_ARC_WITH_SAME_SUPPORTING_CIRCLE
+    // intersection found on the map
     typedef std::vector<CGAL::Object> solutions_container; 
     typedef typename CK::Circular_arc_2 Circular_arc_2; 
 
-#ifdef CGAL_INTERSECTION_MAP_FOR_XMONOTONIC_ARC_WITH_SAME_SUPPORTING_CIRCLE
-    // intersection found on the map
     solutions_container early_sols;
     if(Circular_arc_2::template find_intersection< solutions_container >
       (A1,A2,early_sols)) {
@@ -543,8 +543,8 @@ namespace CircularFunctors {
 	       OutputIterator res )
   {
     typedef std::vector<CGAL::Object> solutions_container; 
-    typedef typename CK::Circular_arc_2 Circular_arc_2; 
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2; 
+    typedef typename CK::Circular_arc_2 Circular_arc_2;
+
 
 #ifdef CGAL_INTERSECTION_MAP_FOR_XMONOTONIC_ARC_WITH_SAME_SUPPORTING_CIRCLE
     // same curve
@@ -566,6 +566,7 @@ namespace CircularFunctors {
 #endif
 
 #ifdef  CGAL_CK_EXPLOIT_IDENTITY
+    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2; 
     bool a1s_a2s = a1.source().equal_ref(a2.source());
     bool a1s_a2t = a1.source().equal_ref(a2.target());
     bool a1t_a2s = a1.target().equal_ref(a2.source());
@@ -1057,9 +1058,6 @@ template < class CK, class OutputIterator >
 		   OutputIterator res )
   {
     typedef typename CK::Circular_arc_2           Circular_arc_2;
-    typedef typename CK::Circle_2                 Circle_2;
-    typedef typename CK::FT                       FT;
-    typedef typename CK::Point_2                  Point_2;
     typedef typename CK::Circular_arc_point_2     Circular_arc_point_2;
     typedef typename CK::Root_for_circles_2_2     Root_for_circles_2_2;
 
@@ -1320,9 +1318,6 @@ template < class CK, class OutputIterator >
 		            OutputIterator res )
   {
     typedef typename CK::Circular_arc_2           Circular_arc_2;
-    typedef typename CK::Circle_2                 Circle_2;
-    typedef typename CK::FT                       FT;
-    typedef typename CK::Point_2                  Point_2;
     typedef std::pair<CGAL::Object,bool >         S_pair;
 
 
@@ -1541,8 +1536,6 @@ advanced_make_xy_monotone( const typename CK::Circular_arc_2 &a,
   CGAL::Bbox_2 circular_arc_bbox
   ( const typename CK::Kernel_base::Circular_arc_2 & a)
   {	
-    typedef typename CK::Root_of_2 	   Root_of_2;
-    typedef typename CK::FT 		   FT;
     typedef CGAL::Interval_nt<false>::Protector IntervalProtector;
     typedef CGAL::Interval_nt<false> Interval; 
 
