@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Circular_kernel_2/include/CGAL/Circular_kernel_2/internal_functions_on_line_arc_2.h $
-// $Id: internal_functions_on_line_arc_2.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Pedro Machado
 
@@ -99,14 +99,14 @@ namespace CircularFunctors {
 
   template< class CK>
   bool
-  is_x_monotone(const typename CK::Line_arc_2 &l)
+  is_x_monotone(const typename CK::Line_arc_2& )
   {
     return true;
   }
 
   template< class CK>
   bool
-  is_y_monotone(const typename CK::Line_arc_2 &l)
+  is_y_monotone(const typename CK::Line_arc_2& )
   {
     return true;
   }
@@ -157,7 +157,6 @@ namespace CircularFunctors {
     if(A2.supporting_line().is_vertical())
       return CGAL::SMALLER;
     
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
     typedef typename CK::Polynomial_1_2       Polynomial_1_2;
     typedef typename CK::Root_of_2            Root_of_2;
 
@@ -418,8 +417,7 @@ namespace CircularFunctors {
     typedef typename CK::Circular_arc_point_2  Circular_arc_point_2;
     typedef typename CK::Line_arc_2               Line_arc_2;
     typedef typename CK::Point_2                  Point_2;
-    typedef typename CK::Root_of_2                Root_of_2;
-    typedef typename CK::Root_for_circles_2_2     Root_for_circles_2_2;
+    // typedef typename CK::Root_for_circles_2_2     Root_for_circles_2_2;
 
 #ifdef CGAL_CK_EXPLOIT_IDENTITY
     bool a1s_a2s = a1.source().equal_ref(a2.source());
@@ -556,12 +554,10 @@ namespace CircularFunctors {
 	       const typename CK::Circular_arc_2 &c,
 	       OutputIterator res )
   {
-    typedef typename CK::Circular_arc_2 Circular_arc_2;
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
-    typedef typename CK::Line_arc_2 Line_arc_2;
     typedef std::vector<CGAL::Object > solutions_container;
 
 #ifdef CGAL_CK_EXPLOIT_IDENTITY
+    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
     bool ls_cs = l.source().equal_ref(c.source());
     bool ls_ct = l.source().equal_ref(c.target());
     bool lt_cs = l.target().equal_ref(c.source());
@@ -661,6 +657,7 @@ namespace CircularFunctors {
     solutions_container solutions;
 
 #ifdef CGAL_INTERSECTION_MAP_FOR_SUPPORTING_CIRCLES
+    typedef typename CK::Line_arc_2 Line_arc_2;
       if(!Line_arc_2::template 
          find_intersection_circle_line< solutions_container > 
          (c,l,solutions)) {
@@ -754,11 +751,7 @@ namespace CircularFunctors {
 	       OutputIterator res )
   {
     typedef typename CK::Circular_arc_point_2  Circular_arc_point_2;
-    typedef typename CK::Line_arc_2               Line_arc_2;
     typedef typename CK::Point_2                  Point_2;
-    typedef typename CK::Line_2                   Line_2;
-    typedef typename CK::Root_of_2                Root_of_2;
-    typedef typename CK::Root_for_circles_2_2     Root_for_circles_2_2;
 
     if(LinearFunctors::non_oriented_equal<CK>(l, la.supporting_line())) {
       *res++ = make_object(la);
@@ -782,9 +775,7 @@ namespace CircularFunctors {
 	       const typename CK::Circular_arc_2 &c,
 	       OutputIterator res )
   {
-    typedef typename CK::Circular_arc_2 Circular_arc_2;
     typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
-    typedef typename CK::Line_2 Line_2;
     typedef std::vector<CGAL::Object > solutions_container;
 
     solutions_container solutions;
@@ -795,9 +786,9 @@ namespace CircularFunctors {
 
     for (typename solutions_container::iterator it = solutions.begin();
 	 it != solutions.end(); ++it) {
-      const std::pair<typename CK::Circular_arc_point_2, unsigned>
+      const std::pair<Circular_arc_point_2, unsigned>
         *result = CGAL::object_cast
-	  <std::pair<typename CK::Circular_arc_point_2, unsigned> > (&(*it));
+	  <std::pair<Circular_arc_point_2, unsigned> > (&(*it));
       if (has_on<CK>(c,result->first,true)) {
 	*res++ = *it;
       }
