@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Triangulation_2/include/CGAL/Constrained_triangulation_2.h $
-// $Id: Constrained_triangulation_2.h 67216 2012-01-17 15:28:40Z sloriot $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Mariette Yvinec, Jean-Daniel Boissonnat
@@ -617,6 +617,11 @@ intersect(Face_handle , int ,
 	  Vertex_handle ,
 	  No_intersection_tag)
 {
+  //SL: I added that to be able to throw while we find a better solution
+  #ifdef CGAL_CT2_WANTS_TO_HAVE_EXTRA_ACTION_FOR_INTERSECTING_CONSTRAINTS
+  CGAL_CDT2_EXTRA_ACTION_FOR_INTERSECTING_CONSTRAINTS
+  #endif
+  
   std::cerr << " sorry, this triangulation does not deal with" 
 	    <<    std::endl
 	    << " intersecting constraints" << std::endl;
