@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Triangulation_2/include/CGAL/Constrained_triangulation_plus_2.h $
-// $Id: Constrained_triangulation_plus_2.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Mariette Yvinec
@@ -25,8 +25,33 @@
 #include <CGAL/Constraint_hierarchy_2.h>
 #include <CGAL/Constrained_Delaunay_triangulation_2.h>
 
+#if defined(BOOST_MSVC)
+#  pragma warning(push)
+#  pragma warning(disable:4355)
+//warning C4355: 'this' : used in base member initializer list
+#endif
+
 namespace CGAL {
 
+// Comparison functor that compares two Vertex_handle.
+// Used as 'Compare' functor for the constraint hierarchy.
+template < class Tr >
+class Ctp2_vertex_handle_less_xy {
+  const Tr* tr_p;
+
+public:
+  Ctp2_vertex_handle_less_xy(const Tr* tr_p) : tr_p(tr_p) {}
+
+  typedef typename Tr::Vertex_handle Vertex_handle;
+
+  bool operator()(const Vertex_handle& va,
+                  const Vertex_handle& vb) const
+  {
+    return tr_p->compare_xy(va->point(), vb->point()) == SMALLER;
+  }
+}; // end class template Ctp2_vertex_handle_less_xy
+
+
 // Tr the base triangulation class 
 // Tr has to be Constrained or Constrained_Delaunay
 
@@ -58,8 +83,11 @@ public:
   typedef typename Triangulation::List_vertices    List_vertices;
   typedef typename Triangulation::List_constraints List_constraints;
 
-  typedef Constraint_hierarchy_2<Vertex_handle, bool> Constraint_hierarchy;
-  typedef Tag_true                                Constraint_hierarchy_tag;
+  typedef Ctp2_vertex_handle_less_xy<Self>         Vh_less_xy;
+  typedef Constraint_hierarchy_2<Vertex_handle, 
+                                 Vh_less_xy,
+                                 bool>             Constraint_hierarchy;
+  typedef Tag_true                                 Constraint_hierarchy_tag;
 
   // for user interface with the constraint hierarchy
   typedef typename Constraint_hierarchy::H_vertex_it    
@@ -88,10 +116,14 @@ protected:
  
 public:
   Constrained_triangulation_plus_2(const Geom_traits& gt=Geom_traits()) 
-    : Triangulation(gt) { }
+    : Triangulation(gt)
+    , hierarchy(Vh_less_xy(this)) 
+  { }
 
   Constrained_triangulation_plus_2(const Self& ctp)
-    : Triangulation()    { copy_triangulation(ctp);}
+    : Triangulation()
+    , hierarchy(Vh_less_xy(this))
+  { copy_triangulation(ctp);}
 
   virtual ~Constrained_triangulation_plus_2() {}
 
@@ -100,6 +132,7 @@ public:
   Constrained_triangulation_plus_2(List_constraints& lc, 
 				   const Geom_traits& gt=Geom_traits())
       : Triangulation(gt)
+      , hierarchy(Vh_less_xy(this))
   {
     typename List_constraints::iterator lcit=lc.begin();
     for( ;lcit != lc.end(); lcit++) {
@@ -113,6 +146,7 @@ public:
 				   InputIterator last,
 				   const Geom_traits& gt=Geom_traits() )
      : Triangulation(gt)
+    , hierarchy(Vh_less_xy(this))
   {
     while( first != last){
       insert_constraint((*first).first, (*first).second);
@@ -237,9 +271,9 @@ public:
  	++it){  
        Face_handle fh;  
        int i;  
-       CGAL_triangulation_assertion_code( bool b = )  
+       CGAL_assume_code( bool b = )
  	Triangulation::is_edge(*it, *succ, fh, i);  
-       CGAL_triangulation_assertion(b);  
+       CGAL_assume(b);
        // this does also flipping if necessary.  
        Triangulation::remove_constrained_edge(fh,i,out);  
  
@@ -655,4 +689,8 @@ vertices_in_constraint_end(Vertex_handle va, Vertex_handle vb)
 
 } //namespace CGAL
 
+#if defined(BOOST_MSVC)
+#  pragma warning(pop)
+#endif
+
 #endif //CGAL_CONSTRAINED_TRIANGULATION_PLUS_2_H
