@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Envelope_3/include/CGAL/Envelope_3/Envelope_divide_and_conquer_3.h $
-// $Id: Envelope_divide_and_conquer_3.h 67537 2012-02-01 08:10:55Z efif $
+// $URL$
+// $Id$
 //
 // Author(s)     : Michal Meyerovitch     <gorgymic@post.tau.ac.il>
 //                 Baruch Zukerman        <baruchzu@post.tau.ac.il>
@@ -1605,7 +1605,7 @@ protected:
 
     virtual void after_split_face(Face_handle org_f,
                                   Face_handle new_f,
-                                  bool is_hole)
+                                  bool /* is_hole*/)
     {
       // update data in the new face from the original face
       if (org_f->get_aux_is_set(0))
