@@ -16,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/STL_Extension/include/CGAL/In_place_list.h $
-// $Id: In_place_list.h 67093 2012-01-13 11:22:39Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
@@ -32,8 +32,6 @@
 #include <iterator>
 #include <functional>
 #include <algorithm>
-#include <CGAL/circulator_impl.h>
-#include <CGAL/circulator.h>
 #include <CGAL/memory.h>
 
 namespace CGAL {
