@@ -16,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Intersections_3/include/CGAL/Intersections_3/intersection_3_1_impl.h $
-// $Id: intersection_3_1_impl.h 67093 2012-01-13 11:22:39Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Geert-Jan Giezeman <geert@cs.uu.nl>
@@ -35,7 +35,7 @@ template <class K>
 Object
 intersection(const typename K::Plane_3  &plane, 
 	     const typename K::Line_3 &line, 
-	     const K&)
+	     const K& k)
 {
     typedef typename K::Point_3 Point_3;
     typedef typename K::Direction_3 Direction_3;
@@ -57,7 +57,7 @@ intersection(const typename K::Plane_3  &plane,
             return Object();
         }
     }
-    return make_object(Point_3(
+    return make_object(k.construct_point_3_object()(
         den*line_pt.hx()-num*line_dir.dx(),
         den*line_pt.hy()-num*line_dir.dy(),
         den*line_pt.hz()-num*line_dir.dz(),
@@ -202,7 +202,6 @@ intersection(const typename K::Line_3 &l1,
 	     const K&)
 {
   typedef typename K::FT           FT;
-  typedef typename K::Line_3       Line_3;
   typedef typename K::Point_3      Point_3;
   typedef typename K::Vector_3     Vector_3;
 
@@ -237,8 +236,6 @@ do_intersect(const typename K::Line_3 &l1,
 	     const typename K::Line_3 &l2,
 	     const K&)
 {
-  typedef typename K::FT           FT;
-  typedef typename K::Line_3       Line_3;
   typedef typename K::Point_3      Point_3;
   typedef typename K::Vector_3     Vector_3;
 
@@ -630,9 +627,7 @@ intersection(const typename K::Plane_3 &p,
              const typename K::Sphere_3 &s,
              const K&)
 {
-  typedef typename K::Sphere_3 Sphere_3;
   typedef typename K::Circle_3 Circle_3;
-  typedef typename K::Plane_3 Plane_3;
   typedef typename K::Point_3 Point_3;
   typedef typename K::FT FT;
   const FT d2 = CGAL::square(p.a()*s.center().x() + 
@@ -656,10 +651,6 @@ do_intersect(const typename K::Plane_3 &p,
              const typename K::Sphere_3 &s,
              const K&)
 {
-  typedef typename K::Sphere_3 Sphere_3;
-  typedef typename K::Circle_3 Circle_3;
-  typedef typename K::Plane_3 Plane_3;
-  typedef typename K::Point_3 Point_3;
   typedef typename K::FT FT;
   const FT d2 = CGAL::square(p.a()*s.center().x() + 
                              p.b()*s.center().y() + 
@@ -673,7 +664,7 @@ inline
 bool
 do_intersect(const typename K::Sphere_3 &s,
              const typename K::Plane_3 &p,
-             const K& k)
+             const K&)
 {
   return do_intersect(p,s);
 }
@@ -697,7 +688,6 @@ intersection(const typename K::Sphere_3 &s1,
              const K& k)
 {
   typedef typename K::Plane_3 Plane_3;
-  typedef typename K::Sphere_3 Sphere_3;
   if(s1.center() == s2.center()) {
     if(s1.squared_radius() == s2.squared_radius()) {
       if(is_zero(s1.squared_radius())) return make_object(s1.center());
@@ -716,7 +706,6 @@ do_intersect(const typename K::Sphere_3 &s1,
              const K& k)
 {
   typedef typename K::Plane_3 Plane_3;
-  typedef typename K::Sphere_3 Sphere_3;
   if(s1.center() == s2.center()) {
     return s1.squared_radius() == s2.squared_radius();
   }
@@ -1095,7 +1084,6 @@ intersection(const typename K::Line_3 &line,
     typedef typename K::Point_3 Point_3;
     typedef typename K::Vector_3 Vector_3;
     typedef typename K::Segment_3 Segment_3;
-    typedef typename K::RT RT;
     typedef typename K::FT FT;
     bool all_values = true;
     FT _min = 0, _max = 0; // initialization to stop compiler warning
@@ -1169,7 +1157,6 @@ intersection(const typename K::Ray_3 &ray,
     typedef typename K::Point_3 Point_3;
     typedef typename K::Vector_3 Vector_3;
     typedef typename K::Segment_3 Segment_3;
-    typedef typename K::RT RT;
     typedef typename K::FT FT;
     bool all_values = true;
     FT _min = 0, _max = 0; // initialization to prevent compiler warning
@@ -1241,7 +1228,6 @@ intersection(const typename K::Segment_3 &seg,
     typedef typename K::Point_3 Point_3;
     typedef typename K::Vector_3 Vector_3;
     typedef typename K::Segment_3 Segment_3;
-    typedef typename K::RT RT;
     typedef typename K::FT FT;
     FT _min = 0, _max;
 
@@ -1320,7 +1306,6 @@ intersection(
     min_points[1] = (icub2.min)();
     max_points[0] = (icub1.max)();
     max_points[1] = (icub2.max)();
-    typedef typename K::FT FT;
     const int DIM = 3;
     int min_idx[DIM];
     int max_idx[DIM];
