@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Number_types/include/CGAL/Lazy_exact_nt.h $
-// $Id: Lazy_exact_nt.h 67093 2012-01-13 11:22:39Z lrineau $
+// $URL$
+// $Id$
 //
 //
 // Author(s)     : Sylvain Pion
@@ -27,10 +27,16 @@
 
 
 #include <CGAL/number_type_basic.h>
+#include <CGAL/assertions.h>
 
 #include <boost/iterator/transform_iterator.hpp> // for Root_of functor
-#include <CGAL/assertions.h>
 #include <boost/operators.hpp>
+#include <boost/type_traits/is_same.hpp>
+#include <boost/type_traits/is_arithmetic.hpp>
+#include <boost/utility/enable_if.hpp>
+
+#include <boost/mpl/if.hpp>
+#include <boost/mpl/logical.hpp>
 
 #include <CGAL/Interval_nt.h>
 #include <CGAL/Handle.h>
@@ -121,13 +127,16 @@ struct Lazy_exact_Int_Cst : public Lazy_exact_nt_rep<ET>
 };
 
 // double constant
-template <typename ET>
+template <typename ET, typename X>
 struct Lazy_exact_Cst : public Lazy_exact_nt_rep<ET>
 {
-  Lazy_exact_Cst (double d)
-      : Lazy_exact_nt_rep<ET>(d) {}
+  Lazy_exact_Cst (X x)
+      : Lazy_exact_nt_rep<ET>(x), cste(x) {}
 
-  void update_exact() const { this->et = new ET(this->approx().inf()); }
+  void update_exact() const { this->et = new ET(cste); }
+
+  private:
+  X cste;
 };
 
 // Exact constant
@@ -341,14 +350,12 @@ public :
   Lazy_exact_nt (Self_rep *r)
     : Base(r) {}
 
-  Lazy_exact_nt (const CGAL_int(ET) & i)
-    : Base(new Lazy_exact_Int_Cst<ET>(i)) {}
-
-  Lazy_exact_nt (unsigned i)
-    : Base(new Lazy_exact_Cst<ET>(i)){}
-
-  Lazy_exact_nt (const CGAL_double(ET) & d)
-    : Base(new Lazy_exact_Cst<ET>(d)){}
+  // Also check that ET and AT are constructible from T?
+  template<class T>
+  Lazy_exact_nt (T i, typename boost::enable_if<boost::mpl::and_<
+      boost::mpl::or_<boost::is_arithmetic<T>, boost::is_enum<T> >,
+      boost::mpl::not_<boost::is_same<T,ET> > >,void*>::type=0)
+    : Base(new Lazy_exact_Cst<ET,T>(i)) {}
 
   Lazy_exact_nt (const ET & e)
     : Base(new Lazy_exact_Ex_Cst<ET>(e)){}
@@ -1370,4 +1377,27 @@ class Modular_traits<Lazy_exact_nt<ET> >
 
 } //namespace CGAL
 
+namespace Eigen {
+  template<class> struct NumTraits;
+  template<typename ET> struct NumTraits<CGAL::Lazy_exact_nt<ET> >
+  {
+    typedef CGAL::Lazy_exact_nt<ET> Real;
+    // typedef CGAL::Lazy_exact_nt<ET> NonInteger;
+    typedef CGAL::Lazy_exact_nt<typename NumTraits<ET>::NonInteger> NonInteger;
+    typedef CGAL::Lazy_exact_nt<ET> Nested;
+
+    static inline Real epsilon() { return 0; }
+
+    enum {
+      IsInteger = NumTraits<ET>::IsInteger,
+      IsSigned = NumTraits<ET>::IsSigned,
+      IsComplex = NumTraits<ET>::IsComplex,
+      RequireInitialization = 1,
+      ReadCost = 8,
+      AddCost = 30,
+      MulCost = 30
+    };
+  };
+}
+
 #endif // CGAL_LAZY_EXACT_NT_H
