@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Mesh_2/include/CGAL/Mesh_2/Refine_edges.h $
-// $Id: Refine_edges.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Laurent RINEAU
@@ -24,6 +24,8 @@
 #include <CGAL/Mesher_level.h>
 #include <CGAL/Meshes/Triangulation_mesher_level_traits_2.h>
 #include <CGAL/Meshes/Filtered_queue_container.h>
+#include <CGAL/tags.h>
+#include <CGAL/assertions.h>
 
 #include <utility>
 #include <iterator>
@@ -127,9 +129,9 @@ namespace Mesh_2 {
     {
       Face_handle fh;
       int i;
-      CGAL_assertion_code( bool should_be_true = )
+      CGAL_assume_code( bool should_be_true = )
       tr.is_edge(va, vb, fh, i);
-      CGAL_assertion( should_be_true == true );
+      CGAL_assume( should_be_true == true );
       
       return this->operator()(tr, fh, i);
     }
@@ -207,9 +209,9 @@ namespace Mesh_2 {
     {
       Face_handle fh;
       int i;
-      CGAL_assertion_code( bool test = )
+      CGAL_assume_code( bool test = )
         tr.is_edge(va, vb, fh, i);
-      CGAL_assertion( test == true );
+      CGAL_assume( test == true );
 
       Vertex_handle vi;
       Vertex_handle mvi;
@@ -422,12 +424,6 @@ public:
     zone.fh = triangulation_ref_impl().locate(p, zone.locate_type, zone.i, edge.first);
 
     const Face_handle n = f->neighbor(i);
-    CGAL_assertion_msg(zone.locate_type != Tr::FACE ||
-                       zone.fh == f || zone.fh == n,
-                       "Your data set contains at least a vertex that is "
-                       "very close to \n"
-                       "  a constrained edge! "
-                       "Mesh_2 cannot mesh that sort of data set.");
 
     const bool f_does_conflict = (zone.locate_type == Tr::EDGE) ||
       triangulation_ref_impl().test_conflict(p, f);
@@ -587,16 +583,16 @@ public:
     Face_handle fh;
     int index;
 
-    CGAL_assertion_code(bool is_edge = )
+    CGAL_assume_code(bool is_edge = )
     tr.is_edge(va, v, fh, index);
-    CGAL_assertion(is_edge == true);
+    CGAL_assume(is_edge == true);
 
     fh->set_constraint(index, true);
     fh->neighbor(index)->set_constraint(triangulation_ref_impl().tds().mirror_index(fh, index), true);
 
-    CGAL_assertion_code( is_edge = )
+    CGAL_assume_code( is_edge = )
     tr.is_edge(vb, v, fh, index);
-    CGAL_assertion(is_edge == true);
+    CGAL_assume(is_edge == true);
 
     fh->set_constraint(index, true);
     fh->neighbor(index)->set_constraint(triangulation_ref_impl().tds().mirror_index(fh, index), true);
@@ -643,7 +639,9 @@ private: /** \name DEBUGGING TYPES AND DATAS */
     {
       Face_handle fh;
       int index;
-      tr.is_edge(edge.first, edge.second, fh, index);
+      CGAL_assume_code(bool sure =)
+        tr.is_edge(edge.first, edge.second, fh, index);
+      CGAL_assume(sure == true);
       return Edge(fh, index);
     }
   }; // end From_pair_of_vertex_to_edge
