@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Mesh_3/include/CGAL/Mesh_3/Refine_facets_3.h $
-// $Id: Refine_facets_3.h 67530 2012-01-31 15:03:44Z lrineau $
+// $URL$
+// $Id$
 //
 //
 // Author(s)     : Stéphane Tayeb
@@ -31,6 +31,8 @@
 #include <CGAL/Meshes/Double_map_container.h>
 #include <CGAL/Meshes/Triangulation_mesher_level_traits_3.h>
 
+#include <CGAL/Object.h>
+
 #include <boost/format.hpp>
 #include <boost/optional.hpp>
 #include <boost/mpl/has_xxx.hpp>
@@ -172,7 +174,7 @@ public:
 
   /// Job to do after insertion
   void after_insertion_impl(const Vertex_handle& v)
-                                          { restore_restricted_Delaunay(v); }
+  { restore_restricted_Delaunay(v); }
 
   /// Insert p into triangulation
   Vertex_handle insert_impl(const Point& p, const Zone& zone);
@@ -213,7 +215,7 @@ private:
   typedef typename Gt::Ray_3 Ray_3;
   typedef typename Gt::Line_3 Line_3;
 
-  typedef typename boost::optional<CGAL::cpp0x::tuple<Surface_patch_index, Index, Point> >
+  typedef typename boost::optional<CGAL::cpp11::tuple<Surface_patch_index, Index, Point> >
                                                                Facet_properties;
 
 private:
@@ -648,9 +650,9 @@ treat_new_facet(Facet& facet)
   Facet_properties properties = compute_facet_properties(facet);
   if ( properties )
   {
-    const Surface_patch_index& surface_index = CGAL::cpp0x::get<0>(*properties);
-    const Index& surface_center_index = CGAL::cpp0x::get<1>(*properties);
-    const Point& surface_center = CGAL::cpp0x::get<2>(*properties);
+    const Surface_patch_index& surface_index = CGAL::cpp11::get<0>(*properties);
+    const Index& surface_center_index = CGAL::cpp11::get<1>(*properties);
+    const Point& surface_center = CGAL::cpp11::get<2>(*properties);
 
     // Facet is on surface: set facet properties
     set_facet_surface_center(facet, surface_center, surface_center_index);
@@ -687,11 +689,12 @@ compute_facet_properties(const Facet& facet) const
   CGAL_assertion( ! r_tr_.is_infinite(facet) );
 
   // types
-  typedef typename MD::Surface_patch Surface_patch;
+  typedef boost::optional<typename MD::Surface_patch_index> Surface_patch;
   typedef typename MD::Intersection Intersection;
 
   // Functor
   typename Gt::Is_degenerate_3 is_degenerate = Gt().is_degenerate_3_object();
+  typename Gt::Compare_xyz_3 compare_xyz = Gt().compare_xyz_3_object();
   typename MD::Do_intersect_surface do_intersect_surface =
       r_oracle_.do_intersect_surface_object();
 
@@ -714,7 +717,7 @@ compute_facet_properties(const Facet& facet) const
       // Trick to have canonical vector : thus, we compute alwais the same
       // intersection
       Segment_3 segment = *p_segment;
-      if ( CGAL::compare_xyz(p_segment->source(),p_segment->target())
+      if ( compare_xyz(p_segment->source(),p_segment->target())
               == CGAL::LARGER )
       {
         typename Gt::Construct_opposite_segment_3 opposite =
@@ -724,9 +727,9 @@ compute_facet_properties(const Facet& facet) const
       }
 
       Intersection intersect = construct_intersection(segment);
-      return Facet_properties(CGAL::cpp0x::make_tuple(*surface,
-                                                CGAL::cpp0x::get<1>(intersect),
-                                                CGAL::cpp0x::get<0>(intersect)));
+      return Facet_properties(CGAL::cpp11::make_tuple(*surface,
+                                                CGAL::cpp11::get<1>(intersect),
+                                                CGAL::cpp11::get<0>(intersect)));
     }
   }
   // If the dual is a ray
@@ -747,9 +750,9 @@ compute_facet_properties(const Facet& facet) const
           r_oracle_.construct_intersection_object();
 
       Intersection intersect = construct_intersection(*p_ray);
-      return Facet_properties(CGAL::cpp0x::make_tuple(*surface,
-                                                CGAL::cpp0x::get<1>(intersect),
-                                                CGAL::cpp0x::get<0>(intersect)));
+      return Facet_properties(CGAL::cpp11::make_tuple(*surface,
+                                                CGAL::cpp11::get<1>(intersect),
+                                                CGAL::cpp11::get<0>(intersect)));
     }
   }
   // If the dual is a line
@@ -764,7 +767,8 @@ compute_facet_properties(const Facet& facet) const
       // Trick to have canonical vector : thus, we compute alwais the same
       // intersection
       Line_3 line = *p_line;
-      if ( CGAL::compare_xyz(p_line->point(0),p_line->point(1))
+      typename Gt::Compare_xyz_3 compare_xyz = Gt().compare_xyz_3_object();
+      if ( compare_xyz(p_line->point(0),p_line->point(1))
               == CGAL::LARGER )
       {
         typename Gt::Construct_opposite_line_3 opposite =
@@ -774,9 +778,9 @@ compute_facet_properties(const Facet& facet) const
       }
 
       Intersection intersect = construct_intersection(line);
-      return Facet_properties(CGAL::cpp0x::make_tuple(*surface,
-                                                CGAL::cpp0x::get<1>(intersect),
-                                                CGAL::cpp0x::get<0>(intersect)));
+      return Facet_properties(CGAL::cpp11::make_tuple(*surface,
+                                                CGAL::cpp11::get<1>(intersect),
+                                                CGAL::cpp11::get<0>(intersect)));
     }
   }
   else
