@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Nef_3/include/CGAL/Nef_3/SNC_io_parser.h $
-// $Id: SNC_io_parser.h 68828 2012-04-24 16:06:55Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Michael Seel    <seel@mpi-sb.mpg.de>
@@ -712,7 +712,6 @@ class Geometry_io<Cartesian_tag, Kernel> {
     void print_point(std::ostream& out, const CGAL::Point_3<R> p) {
     typedef Fraction_traits<typename R::FT> FracTraits;
     typedef std::vector<typename FracTraits::Numerator_type> NV;
-    typedef typename NV::iterator NV_iter;
 
     typename FracTraits::Numerator_type num;
     typename FracTraits::Denominator_type denom;
@@ -745,7 +744,6 @@ class Geometry_io<Cartesian_tag, Kernel> {
     typedef Fraction_traits<typename R::FT> FracTraits;
     typedef typename FracTraits::Numerator_type NumType;
     typedef std::vector<NumType> NV;
-    typedef typename NV::iterator NV_iter;
 
     typename FracTraits::Numerator_type num;
     typename FracTraits::Denominator_type denom;
@@ -774,7 +772,6 @@ class Geometry_io<Cartesian_tag, Kernel> {
   void print_plane(std::ostream& out, const CGAL::Plane_3<R> p) {
     typedef Fraction_traits<typename R::FT> FracTraits;
     typedef std::vector<typename FracTraits::Numerator_type> NV;
-    typedef typename NV::iterator NV_iter;
 
     typename FracTraits::Numerator_type num;
     typename FracTraits::Denominator_type denom;
