@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Nef_S2/include/CGAL/Nef_S2/SM_overlayer.h $
-// $Id: SM_overlayer.h 68828 2012-04-24 16:06:55Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
@@ -336,12 +336,12 @@ void link_as_target_and_append(SVertex_handle v, SHalfedge_handle e)
 SHalfedge_handle new_halfedge_pair_at_source(SVertex_handle v)
 { return G.new_shalfedge_pair_at_source(v,Graph::BEFORE); }
 
-void supporting_segment(SHalfedge_handle e, ITERATOR it) {}
-void halfedge_below(SVertex_handle v, SHalfedge_handle e) {}
-void trivial_segment(SVertex_handle v, ITERATOR it) {}
-void starting_segment(SVertex_handle v, ITERATOR it) {}
-void passing_segment(SVertex_handle v, ITERATOR it) {}
-void ending_segment(SVertex_handle v, ITERATOR it) {}
+void supporting_segment(SHalfedge_handle /*e*/, ITERATOR /*it*/) {}
+void halfedge_below(SVertex_handle /*v*/, SHalfedge_handle /*e*/) {}
+void trivial_segment(SVertex_handle /*v*/, ITERATOR /*it*/) {}
+void starting_segment(SVertex_handle /*v*/, ITERATOR /*it*/) {}
+void passing_segment(SVertex_handle /*v*/, ITERATOR /*it*/) {}
+void ending_segment(SVertex_handle /*v*/, ITERATOR /*it*/) {}
 
 
 }; // SMO_decorator
@@ -376,7 +376,7 @@ public:
 
   The faces refer to the maximal connected open point sets of the
   spherical subdivision implied by the embedding of the vertices and
-  edges.  SFaces are bounded by possibly several face cycles\footnote{For
+  edges.  SFaces are bounded by possibly several face cycles\cgalFootnote{For
   the definition of sphere maps and their concepts see the manual page
   of |SM_decorator|.} including isolated vertices. The overlay process
   in the method |create_from_segments| creates the objects and the
