@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Polyhedron/include/CGAL/Polyhedron_incremental_builder_3.h $
-// $Id: Polyhedron_incremental_builder_3.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Lutz Kettner  <kettner@mpi-sb.mpg.de>)
@@ -570,7 +570,7 @@ begin_surface( std::size_t v, std::size_t f, std::size_t h, int mode) {
         // not know the number of facets that are holes and we do not
         // know the genus of the surface. So we add 12 and a factor of
         // 5 percent.
-        h = int((v + f - 2 + 12) * 2.1);
+      h = (std::size_t)((double)(v + f - 2 + 12) * 2.1);
     }
     hds.reserve( hds.size_of_vertices()  + v,
                  hds.size_of_halfedges() + h,
