@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Polynomial/include/CGAL/Polynomial/Polynomial_type.h $
-// $Id: Polynomial_type.h 67240 2012-01-18 09:57:46Z afabri $
+// $URL$
+// $Id$
 //
 //
 // Author(s)     : Michael Hemmer <hemmer@informatik.uni-mainz.de> 
@@ -41,9 +41,12 @@ typename CGAL::internal::Innermost_coefficient_type<T>::Type , 2>::Type
 
 
 #include <CGAL/ipower.h>
+#include <cstdio>
 #include <sstream>
 #include <CGAL/Polynomial/misc.h>
 
+#include <CGAL/use.h>
+
 #ifdef CGAL_HAS_THREADS
 #  include <boost/thread/tss.hpp>
 #endif
@@ -899,6 +902,7 @@ public:
         //   the terms of q and hence in NT.
         Polynomial<NT> q, r;
         Polynomial<NT>::euclidean_division(p1, p2, q, r);
+        CGAL_USE_TYPE(AST);
         CGAL_postcondition( !AST::Is_exact::value || p2 * q == p1);
         return (*this) = q;
       }
@@ -1158,6 +1162,7 @@ void Polynomial<NT>::pseudo_division(
   if (delta < 0 || A.is_zero()) {
     Q = Polynomial<NT>(NT(0)); R = A; D = NT(1);
        
+    CGAL_USE_TYPE(AST);
     CGAL_postcondition( !AST::Is_exact::value || Polynomial<NT>(D)*A == Q*B + R);
     return;
   }
@@ -1330,7 +1335,7 @@ void Polynomial<NT>::output_maple(std::ostream& os) const {
     static const char *varnames[] = { "x", "y", "z" };
     varname = varnames[Polynomial_traits_d<NT>::d];
   } else {
-    sprintf(vnbuf, "w%d", Polynomial_traits_d<NT>::d - 2);
+    std::sprintf(vnbuf, "w%d", Polynomial_traits_d<NT>::d - 2);
     varname = vnbuf;
   }
     
