@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Skin_surface_3/include/CGAL/Skin_surface_base_3.h $
-// $Id: Skin_surface_base_3.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Nico Kruithof <Nico@cs.rug.nl>
@@ -498,7 +498,6 @@ construct_bounding_box()
 {
   typedef typename Regular::Finite_vertices_iterator Finite_vertices_iterator;
   typedef typename Regular::Geom_traits     GT;
-  typedef typename GT::Bare_point             Point;
   typedef typename GT::Point                Weighted_point;
   typedef typename GT::FT                     FT;
   
