@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Surface_mesher/include/CGAL/Surface_mesher/Surface_mesher_edges_level.h $
-// $Id: Surface_mesher_edges_level.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Laurent RINEAU
@@ -30,6 +30,7 @@
 #include <CGAL/circulator.h> // for CGAL::Circulator_from_container<C>
 #include <sstream>
 #include <boost/format.hpp>
+#include <CGAL/use.h>
 
 namespace CGAL {
 namespace Surface_mesher {
@@ -95,12 +96,8 @@ namespace Surface_mesher {
     typedef typename Tr::Cell_handle Cell_handle;
     typedef typename GT::Point_3 Point_3;
     typedef typename GT::Triangle_3 Triangle_3;
-    typedef typename GT::Sphere_3 Sphere_3;
-    typedef typename GT::Ray_3 Ray_3;
-    typedef typename GT::Line_3 Line_3;
     typedef typename GT::Vector_3 Vector_3;
     typedef typename GT::FT FT;
-    typedef typename Surface_mesh_traits::Surface_3 Surface_3;
     typedef typename Surface_mesh_traits::Intersection_point Intersection_point;
 
     typename GT::Construct_midpoint_3 midpoint = 
@@ -125,7 +122,6 @@ namespace Surface_mesher {
       tr.geom_traits().compute_squared_length_3_object();
 
     typedef std::vector<Point_3> Edge_dual;
-    typedef typename Edge_dual::size_type size_type;
     Edge_dual edge_dual;
     edge_dual.reserve(12);
 
@@ -149,6 +145,8 @@ namespace Surface_mesher {
 					// incident cell.
     typename Tr::Cell_circulator begin = circ;
 
+    typedef typename Edge_dual::size_type size_type;
+    CGAL_USE_TYPE(size_type);
     CGAL_assertion_code(size_type number_of_finite_incident_cells = 0);
     CGAL_assertion_code(size_type number_of_infinite_incident_cells = 0);
 
