@@ -16,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/STL_Extension/include/CGAL/Threetuple.h $
-// $Id: Threetuple.h 67093 2012-01-13 11:22:39Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Andreas Fabri
@@ -25,6 +25,8 @@
 #ifndef CGAL_THREETUPLE_H
 #define CGAL_THREETUPLE_H
 
+#include <CGAL/config.h>
+
 #ifndef CGAL_NO_DEPRECATED_CODE
 
 namespace CGAL {
