@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Triangulation_2/include/CGAL/Triangulation_data_structure_2.h $
-// $Id: Triangulation_data_structure_2.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Mariette Yvinec
@@ -31,6 +31,7 @@
 #include <algorithm>
 #include <boost/tuple/tuple.hpp>
 
+#include <CGAL/Unique_hash_map.h>
 #include <CGAL/triangulation_assertions.h>
 #include <CGAL/Triangulation_utils_2.h>
  
@@ -62,6 +63,17 @@ class Triangulation_data_structure_2
   friend class Triangulation_ds_vertex_circulator_2<Tds>;
 
 public:
+  // Tools to change the Vertex and Face types of the TDS.
+  template < typename Vb2 >
+  struct Rebind_vertex {
+    typedef Triangulation_data_structure_2<Vb2, Fb>  Other;
+  };
+
+  template < typename Fb2 >
+  struct Rebind_face {
+    typedef Triangulation_data_structure_2<Vb, Fb2>  Other;
+  };
+
   typedef Vertex_base                                Vertex;
   typedef Face_base                                  Face;
   
@@ -211,7 +223,10 @@ public:
     CGAL_triangulation_precondition (f->neighbor(i) != Face_handle() &&
 				     f->dimension() >= 1);
     if (f->dimension() == 1) {
-      return 1 - (f->neighbor(i)->index(f->vertex(1-i)));
+      CGAL_assertion(i<=1);
+      const int j = f->neighbor(i)->index(f->vertex((i==0) ? 1 : 0));
+      CGAL_assertion(j<=1);
+      return (j==0) ? 1 : 0;
     }
     return ccw( f->neighbor(i)->index(f->vertex(ccw(i))));
   }
@@ -286,7 +301,7 @@ public:
 			  Face_handle f1, 
 			  Face_handle f2, 
 			  Face_handle f3);
-    void set_adjacency(Face_handle f0, int i0, Face_handle f1, int i1) const;
+  void set_adjacency(Face_handle f0, int i0, Face_handle f1, int i1) const;
   void delete_face(Face_handle);
   void delete_vertex(Vertex_handle);
 
@@ -1772,8 +1787,8 @@ copy_tds(const Tds &tds, Vertex_handle vh)
   if(n == 0) {return Vertex_handle();}
   
   //initializes maps
-  std::map<Vertex_handle,Vertex_handle> vmap;
-  std::map<Face_handle,Face_handle> fmap;
+  Unique_hash_map<Vertex_handle,Vertex_handle> vmap;
+  Unique_hash_map<Face_handle,Face_handle> fmap;
 
   // create vertices
   Vertex_iterator vit1 = tds.vertices_begin();
@@ -1825,8 +1840,9 @@ file_output( std::ostream& os, Vertex_handle v, bool skip_first) const
   else     os << n << m << dimension();
   if (n==0) return;
 
-  std::map<Vertex_handle,int> V;
-  std::map<Face_handle,int> F;
+  Unique_hash_map<Vertex_handle,int> V;
+  Unique_hash_map<Face_handle,int> F;
+
 
   // first vertex 
   int inum = 0;
@@ -1961,7 +1977,8 @@ vrml_output( std::ostream& os, Vertex_handle v, bool skip_infinite) const
   os << "\t\tcoord Coordinate {" << std::endl;
   os << "\t\t\tpoint [" << std::endl;
 
-  std::map<Vertex_handle,int> vmap;
+  Unique_hash_map<Vertex_handle,int> vmap;
+
   Vertex_iterator vit;
   Face_iterator fit;
 
@@ -2030,7 +2047,7 @@ off_file_input( std::istream& is, bool verbose)
   typedef typename Vb::Point   Point;
 
   // read vertices
-  int i;
+  std::size_t i;
   for ( i = 0; i < scanner.size_of_vertices(); i++) {
     Point p;
     file_scan_vertex( scanner, p);
@@ -2060,14 +2077,14 @@ off_file_input( std::istream& is, bool verbose)
       return vinf;
     }
 
-    for ( int j = 0; j < no; ++j) {
+    for ( std::size_t j = 0; j < no; ++j) {
       std::size_t index;
       scanner.scan_facet_vertex_index( index, i);
       fh->set_vertex(j, vvh[index]);
       vvh[index]->set_face(fh);
     }
 
-    for (int ih  = 0; ih < no; ++ih) {
+    for (std::size_t ih  = 0; ih < no; ++ih) {
 	set_adjacency(fh, ih, edge_map);
     }
   }
