@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Triangulation_3/include/CGAL/Triangulation_hierarchy_3.h $
-// $Id: Triangulation_hierarchy_3.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 //
 // Author(s)     : Olivier Devillers <Olivier.Devillers@sophia.inria.fr>
 //                 Sylvain Pion
@@ -176,9 +176,9 @@ public:
     std::vector<Vertex_handle> vo(first, beyond), vc;
     int l=0;
     while(1) {
-      int n = vo.size();
-      if(!n) break;
-      for(int i=0; i<n; i++) {
+      size_type n = vo.size();
+      if(n == 0) break;
+      for(size_type i=0; i<n; i++) {
         if(vo[i]->up() != Vertex_handle()) vc.push_back(vo[i]->up());
       }
       hierarchy[l++]->remove_cluster(vo.begin(), vo.end());
@@ -207,7 +207,7 @@ public: // some internal methods
 		
   template <class OutputItCells>
   Vertex_handle insert_and_give_new_cells(const Point& p,
-                                          OutputItCells fit,
+                                          OutputItCells /* fit */,
                                           Vertex_handle hint)
   {
     return insert_and_give_new_cells(p, hint == Vertex_handle() ? 
