@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2.h $
-// $Id: Voronoi_diagram_2.h 68301 2012-03-30 16:05:40Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@iacm.forth.gr>
@@ -323,15 +323,15 @@ public:
   //------------------
 
   // VORONOI FEATURES FROM DELAUNAY FEATURES
-  Halfedge_handle dual(Delaunay_edge& e) const {
+  Halfedge_handle dual(const Delaunay_edge& e) const {
     return Halfedge_handle( Halfedge(this, e.first, e.second) );
   }
 
-  Face_handle dual(Delaunay_vertex_handle& v) const {
+  Face_handle dual(Delaunay_vertex_handle v) const {
     return Face_handle( Face(this, v) );
   }
 
-  Vertex_handle dual(Delaunay_face_handle& f) const {
+  Vertex_handle dual(Delaunay_face_handle f) const {
     return Vertex_handle( Vertex(this, f) );
   }
 
@@ -614,6 +614,7 @@ public:
 
   Halfedge_around_vertex_circulator
   incident_halfedges(const Vertex_handle& v, const Halfedge_handle& he) const {
+    internal::use(v);
     CGAL_precondition( he->target() == v );
     return Halfedge_around_vertex_circulator(*he);
   }
@@ -621,7 +622,7 @@ public:
   // POINT LOCATION
   //---------------
  private:
-  Locate_result locate(const Point_2& p, const Tag_false&) const {
+  Locate_result locate(const Point_2& , const Tag_false&) const {
     static unsigned int i = 0;
     if ( i == 0 ) {
       i++;
