@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Kernel_23/include/CGAL/internal/Projection_traits_3.h $
-// $Id: Projection_traits_3.h 67093 2012-01-13 11:22:39Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Mariette Yvinec, Sebastien Loriot
@@ -27,6 +27,8 @@
 #include <CGAL/Segment_3.h>
 #include <CGAL/Triangle_3.h>
 
+#include <CGAL/Kernel/global_functions_2.h>
+
 namespace CGAL { 
 
 namespace internal {
@@ -181,6 +183,33 @@ public:
   }
 };
 
+template <class R, int dim>
+class Less_signed_distance_to_line_projected_3
+{
+public:
+  typedef typename R::Point_3   Point_3;
+  typedef typename R::Point_2   Point_2;
+  typedef typename R::FT        RT;
+  typename R::FT x(const Point_3 &p) const { return Projector<R,dim>::x(p); }
+  typename R::FT y(const Point_3 &p) const { return Projector<R,dim>::y(p); }
+  typedef bool result_type;
+
+  Point_2 project(const Point_3& p) const
+  {
+    return Point_2(x(p),y(p));
+  }
+
+  result_type operator()(const Point_3& p,
+                               const Point_3& q,
+                               const Point_3& r,
+                               const Point_3& s) const
+  {
+    return typename R::Less_signed_distance_to_line_2()
+      (  project(p), project(q), project(r), project(s) );
+  }
+};
+
+
 template <class R,int dim>
 class Squared_distance_projected_3
 {
@@ -198,6 +227,13 @@ public:
     return Point_2(x(p),y(p));
   }
 
+  RT operator()(const Point_3& p, const Point_3& q) const
+  {
+	  Point_2 p2(project(p));
+	  Point_2 q2(project(q));
+	  return squared_distance(p2, q2);
+  }
+
   RT operator()(const Line_3& l, const Point_3& p) const
   {
     Point_2 p2(project(p));
@@ -225,6 +261,13 @@ public:
     return Point_2(x(p),y(p));
   }
 
+  FT alpha(const Point_2& p, const Point_2& source, const Point_2& target) const
+  {
+    FT dx = target.x() - source.x();
+    FT dy = target.y() - source.y();
+    return (CGAL::abs(dx)>CGAL::abs(dy)) ? ( p.x()-source.x() ) / dx : (p.y()-source.y() ) / dy;
+  }
+
   Object operator()(const Segment_3& s1, const Segment_3& s2) const
   {
     Point_2 s1_source = project(s1.source());
@@ -244,15 +287,15 @@ public:
       const Segment_2* si=CGAL::object_cast<Segment_2>(&o);
       if (si==NULL) return Object();
       FT src[3],tgt[3];
-      tgt[dim] = src[dim] = FT(0); //the third coordinate is the midpoint between the points on s1 and s2
-
-      FT z1 = s1.source()[dim] + ( si->source().x()-s1_source.x() ) / (s1_target.x() - s1_source.x()) * ( s1.target()[dim] - s1.source()[dim] );
-      FT z2 = s2.source()[dim] + ( si->source().x()-s2_source.x() ) / (s2_target.x() - s2_source.x()) * ( s2.target()[dim] - s2.source()[dim] );
+      //the third coordinate is the midpoint between the points on s1 and s2
+      FT z1 = s1.source()[dim] + ( alpha(si->source(), s1_source, s1_target) * ( s1.target()[dim] - s1.source()[dim] ));
+      FT z2 = s2.source()[dim] + ( alpha(si->source(), s2_source, s2_target) * ( s2.target()[dim] - s2.source()[dim] ));
       src[dim] = (z1+z2) / FT(2);
 
 
-      z1 = s1.source()[dim] + ( si->target().x()-s1_source.x() ) / (s1_target.x() - s1_source.x()) * ( s1.target()[dim] - s1.source()[dim] );
-      z2 = s2.source()[dim] + ( si->target().x()-s2_source.x() ) / (s2_target.x() - s2_source.x()) * ( s2.target()[dim] - s2.source()[dim] );
+      z1 = s1.source()[dim] + ( alpha(si->target(), s1_source, s1_target) * ( s1.target()[dim] - s1.source()[dim] ));
+      z2 = s2.source()[dim] + ( alpha(si->target(), s2_source, s2_target) * ( s2.target()[dim] - s2.source()[dim] ));
+
       tgt[dim] = (z1+z2) / FT(2);
 
 
@@ -264,8 +307,8 @@ public:
     }
     FT coords[3];
     //compute the third coordinate of the projected intersection point onto 3D segments
-    FT z1 = s1.source()[dim] + ( pi->x()-s1_source.x() ) / (s1_target.x() - s1_source.x()) * ( s1.target()[dim] - s1.source()[dim] );
-    FT z2 = s2.source()[dim] + ( pi->x()-s2_source.x() ) / (s2_target.x() - s2_source.x()) * ( s2.target()[dim] - s2.source()[dim] );
+    FT z1 = s1.source()[dim] + ( alpha(*pi, s1_source, s1_target) * ( s1.target()[dim] - s1.source()[dim] ));
+    FT z2 = s2.source()[dim] + ( alpha(*pi, s2_source, s2_target) * ( s2.target()[dim] - s2.source()[dim] ));
 
     coords[dim] = (z1+z2) / FT(2);
     coords[Projector<R,dim>::x_index] = pi->x();
@@ -373,6 +416,7 @@ public:
   typedef typename R::FT                                      FT;
   typedef typename Rp::Point_3                                Point_2;
   typedef typename Rp::Segment_3                              Segment_2;
+  typedef typename Rp::Vector_3                               Vector_2;
   typedef typename Rp::Triangle_3                             Triangle_2;
   typedef typename Rp::Line_3                                 Line_2;
 
@@ -381,13 +425,19 @@ public:
   typedef typename Projector<R,dim>::Compare_x_2              Compare_x_2;
   typedef typename Projector<R,dim>::Compare_y_2              Compare_y_2;
   typedef Orientation_projected_3<Rp,dim>                     Orientation_2;
+  typedef typename Rp::Angle_3                                Angle_2;
   typedef Side_of_oriented_circle_projected_3<Rp,dim>         Side_of_oriented_circle_2;
-  typedef Side_of_bounded_circle_projected_3<Rp,dim>         Side_of_bounded_circle_2;
+  typedef Less_signed_distance_to_line_projected_3<Rp,dim>    Less_signed_distance_to_line_2;
+  typedef Side_of_bounded_circle_projected_3<Rp,dim>          Side_of_bounded_circle_2;
   typedef Compare_distance_projected_3<Rp,dim>                Compare_distance_2;
   typedef Squared_distance_projected_3<Rp,dim>                Compute_squared_distance_2;
   typedef Intersect_projected_3<Rp,dim>                       Intersect_2;
   typedef Compute_squared_radius_projected<Rp,dim>            Compute_squared_radius_2;
   typedef typename Rp::Construct_segment_3                    Construct_segment_2;
+  typedef typename Rp::Construct_translated_point_3           Construct_translated_point_2;
+  typedef typename Rp::Construct_midpoint_3                   Construct_midpoint_2;
+  typedef typename Rp::Construct_vector_3                     Construct_vector_2;
+  typedef typename Rp::Construct_scaled_vector_3              Construct_scaled_vector_2;
   typedef typename Rp::Construct_triangle_3                   Construct_triangle_2;
   typedef typename Rp::Construct_line_3                       Construct_line_2;
 
@@ -483,12 +533,20 @@ public:
   less_yx_2_object() const
     { return Less_yx_2();}
 
+  Less_signed_distance_to_line_2
+    less_signed_distance_to_line_2_object() const
+    {return Less_signed_distance_to_line_2();}
+
   Less_y_2
   less_y_2_object() const
     { return Less_y_2();}
   Compare_x_2
   compare_x_2_object() const
     { return Compare_x_2();}
+  Angle_2
+  angle_2_object() const {
+	  return Angle_2();
+  }
 
   Compare_y_2
   compare_y_2_object() const
@@ -533,6 +591,18 @@ public:
   Construct_segment_2  construct_segment_2_object() const
     {return Construct_segment_2();}
 
+  Construct_translated_point_2  construct_translated_point_2_object() const
+    {return Construct_translated_point_2();}
+
+  Construct_midpoint_2  construct_midpoint_2_object() const
+    {return Construct_midpoint_2();}
+
+  Construct_vector_2  construct_vector_2_object() const
+    {return Construct_vector_2();}
+
+  Construct_scaled_vector_2  construct_scaled_vector_2_object() const
+    {return Construct_scaled_vector_2();}
+
   Construct_triangle_2  construct_triangle_2_object() const
     {return Construct_triangle_2();}
     
