@@ -16,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/STL_Extension/include/CGAL/iterator.h $
-// $Id: iterator.h 67093 2012-01-13 11:22:39Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
@@ -29,11 +29,13 @@
 
 #include <CGAL/circulator.h>
 #include <CGAL/assertions.h>
+#include <CGAL/use.h>
 #include <vector>
 #include <map>
-#include <boost/type_traits.hpp>
 #include <CGAL/tuple.h>
 
+#include <boost/config.hpp>
+
 #if defined(BOOST_MSVC)
 #  pragma warning(push)
 #  pragma warning(disable:4396)
@@ -318,6 +320,7 @@ public:
 
   Iterator  current_iterator() const { return nt;}
   bool operator==( Nullptr_t p) const {
+    CGAL_USE(p);
     CGAL_assertion( p == 0);
     return empty;
   }
@@ -1185,11 +1188,11 @@ filter_output_iterator(I e, const P& p)
 { return Filter_output_iterator< I, P >(e, p); }
 
 
-#ifndef CGAL_CFG_NO_CPP0X_VARIADIC_TEMPLATES
+#if !defined(CGAL_CFG_NO_CPP0X_VARIADIC_TEMPLATES) && !defined(CGAL_CFG_NO_CPP0X_TUPLE)
 
 namespace internal {
 
-template < typename D, typename V = cpp0x::tuple<>, typename O = cpp0x::tuple<> >
+template < typename D, typename V = cpp11::tuple<>, typename O = cpp11::tuple<> >
 struct Derivator
 {
 #ifndef CGAL_CFG_NO_CPP0X_DELETED_AND_DEFAULT_FUNCTIONS
@@ -1199,11 +1202,11 @@ struct Derivator
 };
 
 template < typename D, typename V1, typename O1, typename... V, typename... O>
-struct Derivator<D, cpp0x::tuple<V1, V...>, cpp0x::tuple<O1, O...> >
-  : public Derivator<D, cpp0x::tuple<V...>, cpp0x::tuple<O...> >
+struct Derivator<D, cpp11::tuple<V1, V...>, cpp11::tuple<O1, O...> >
+  : public Derivator<D, cpp11::tuple<V...>, cpp11::tuple<O...> >
 {
-  typedef Derivator<D, cpp0x::tuple<V1, V...>, cpp0x::tuple<O1, O...> > Self;
-  typedef Derivator<D, cpp0x::tuple<V...>, cpp0x::tuple<O...> > Base;
+  typedef Derivator<D, cpp11::tuple<V1, V...>, cpp11::tuple<O1, O...> > Self;
+  typedef Derivator<D, cpp11::tuple<V...>, cpp11::tuple<O...> > Base;
 
 #ifndef CGAL_CFG_NO_CPP0X_DELETED_AND_DEFAULT_FUNCTIONS
   Self& operator=(const Self&) = delete;
@@ -1213,7 +1216,7 @@ struct Derivator<D, cpp0x::tuple<V1, V...>, cpp0x::tuple<O1, O...> >
   
   D& operator=(const V1& v)
   {
-    * cpp0x::get< D::size - sizeof...(V) - 1 >(static_cast<typename D::Iterator_tuple&>(static_cast<D&>(*this))) ++ = v;
+    * cpp11::get< D::size - sizeof...(V) - 1 >(static_cast<typename D::Iterator_tuple&>(static_cast<D&>(*this))) ++ = v;
     return static_cast<D&>(*this);
   }
 };
@@ -1227,9 +1230,9 @@ template < typename V, typename O >
 class Dispatch_output_iterator;
 
 template < typename... V, typename... O >
-class Dispatch_output_iterator < cpp0x::tuple<V...>, cpp0x::tuple<O...> >
- : private internal::Derivator<Dispatch_output_iterator< cpp0x::tuple<V...>, cpp0x::tuple<O...> >, cpp0x::tuple<V...>, cpp0x::tuple<O...> >
- , public cpp0x::tuple<O...>
+class Dispatch_output_iterator < cpp11::tuple<V...>, cpp11::tuple<O...> >
+ : private internal::Derivator<Dispatch_output_iterator< cpp11::tuple<V...>, cpp11::tuple<O...> >, cpp11::tuple<V...>, cpp11::tuple<O...> >
+ , public cpp11::tuple<O...>
 {
   CGAL_static_assertion_msg(sizeof...(V) == sizeof...(O),
                 "The number of explicit template parameters has to match the number of arguments");
@@ -1237,12 +1240,12 @@ class Dispatch_output_iterator < cpp0x::tuple<V...>, cpp0x::tuple<O...> >
   static const int size = sizeof...(V);
 
   template <typename D, typename V_, typename O_>
-  friend class internal::Derivator;
+  friend struct internal::Derivator;
 
 public:
 
-  typedef cpp0x::tuple<O...>               Iterator_tuple;
-  typedef cpp0x::tuple<V...>               Value_type_tuple;
+  typedef cpp11::tuple<O...>               Iterator_tuple;
+  typedef cpp11::tuple<V...>               Value_type_tuple;
 
   typedef std::output_iterator_tag  iterator_category;
   typedef void                      value_type;
@@ -1259,7 +1262,7 @@ public:
 
   using Base::operator=;
 
-  Dispatch_output_iterator(O... o) : cpp0x::tuple<O...>(o...) {}
+  Dispatch_output_iterator(O... o) : cpp11::tuple<O...>(o...) {}
 
   Self& operator=(const Self& s)
   {
@@ -1275,10 +1278,10 @@ public:
 };
 
 template < typename... V, typename... O>
-Dispatch_output_iterator<cpp0x::tuple<V...>, cpp0x::tuple<O...> >
+Dispatch_output_iterator<cpp11::tuple<V...>, cpp11::tuple<O...> >
 dispatch_output(O... o)
 {
-  return Dispatch_output_iterator<cpp0x::tuple<V...>, cpp0x::tuple<O...> > (o...);
+  return Dispatch_output_iterator<cpp11::tuple<V...>, cpp11::tuple<O...> > (o...);
 }
 
 
@@ -1289,14 +1292,14 @@ template < typename V, typename O >
 class Dispatch_or_drop_output_iterator;
 
 template < typename... V, typename... O >
-class Dispatch_or_drop_output_iterator < cpp0x::tuple<V...>, cpp0x::tuple<O...> >
- : public Dispatch_output_iterator< cpp0x::tuple<V...>, cpp0x::tuple<O...> >
+class Dispatch_or_drop_output_iterator < cpp11::tuple<V...>, cpp11::tuple<O...> >
+ : public Dispatch_output_iterator< cpp11::tuple<V...>, cpp11::tuple<O...> >
 {
   typedef Dispatch_or_drop_output_iterator Self;
-  typedef Dispatch_output_iterator< cpp0x::tuple<V...>, cpp0x::tuple<O...> > Base;
+  typedef Dispatch_output_iterator< cpp11::tuple<V...>, cpp11::tuple<O...> > Base;
 
   template <typename D, typename V_, typename O_>
-  friend class internal::Derivator;
+  friend struct internal::Derivator;
 
 public:
 
@@ -1315,10 +1318,10 @@ public:
 
 template < typename... V, typename... O>
 inline
-Dispatch_or_drop_output_iterator<cpp0x::tuple<V...>, cpp0x::tuple<O...> >
+Dispatch_or_drop_output_iterator<cpp11::tuple<V...>, cpp11::tuple<O...> >
 dispatch_or_drop_output(O... o)
 {
-  return Dispatch_or_drop_output_iterator<cpp0x::tuple<V...>, cpp0x::tuple<O...> >(o...);
+  return Dispatch_or_drop_output_iterator<cpp11::tuple<V...>, cpp11::tuple<O...> >(o...);
 }
 
 #else
@@ -1334,12 +1337,12 @@ class Dispatch_or_drop_output_iterator;
 
 // Version with 1 parameters
 template<class V1,class O1>
-class Dispatch_output_iterator<cpp0x::tuple<V1>,cpp0x::tuple<O1> >:public cpp0x::tuple<O1>{
+class Dispatch_output_iterator<cpp11::tuple<V1>,cpp11::tuple<O1> >:public cpp11::tuple<O1>{
   typedef Dispatch_output_iterator Self;
   
 public:
-  typedef cpp0x::tuple<V1> Value_type_tuple;
-  typedef cpp0x::tuple<O1> Iterator_tuple;
+  typedef cpp11::tuple<V1> Value_type_tuple;
+  typedef cpp11::tuple<O1> Iterator_tuple;
   typedef std::output_iterator_tag iterator_category;
   typedef void                     value_type;
   typedef void                     difference_type;
@@ -1359,7 +1362,7 @@ public:
   {}
   
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
@@ -1376,19 +1379,19 @@ public:
 
 template<class V1,class O1>
 inline 
-Dispatch_output_iterator<cpp0x::tuple<V1>,cpp0x::tuple<O1> >
+Dispatch_output_iterator<cpp11::tuple<V1>,cpp11::tuple<O1> >
 dispatch_output(O1 out1){
-  return Dispatch_output_iterator<cpp0x::tuple<V1>,cpp0x::tuple<O1> >(out1);
+  return Dispatch_output_iterator<cpp11::tuple<V1>,cpp11::tuple<O1> >(out1);
 }
 
 //Version with DROP
 
 template<class V1,class O1>
-class Dispatch_or_drop_output_iterator<cpp0x::tuple<V1>,cpp0x::tuple<O1> >:
-        public Dispatch_output_iterator<cpp0x::tuple<V1>,cpp0x::tuple<O1> >
+class Dispatch_or_drop_output_iterator<cpp11::tuple<V1>,cpp11::tuple<O1> >:
+        public Dispatch_output_iterator<cpp11::tuple<V1>,cpp11::tuple<O1> >
 {
   typedef Dispatch_or_drop_output_iterator Self;
-  typedef Dispatch_output_iterator<cpp0x::tuple<V1>,cpp0x::tuple<O1> > Base;
+  typedef Dispatch_output_iterator<cpp11::tuple<V1>,cpp11::tuple<O1> > Base;
   
 public:
 
@@ -1399,10 +1402,10 @@ public:
   Dispatch_or_drop_output_iterator(O1 out1):Base(out1){}
   
   #if defined(__EDG__)  
-  typedef cpp0x::tuple<O1> Iterator_tuple;
+  typedef cpp11::tuple<O1> Iterator_tuple;
     
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
@@ -1423,19 +1426,19 @@ public:
 
 template<class V1,class O1>
 inline 
-Dispatch_or_drop_output_iterator<cpp0x::tuple<V1>,cpp0x::tuple<O1> >
+Dispatch_or_drop_output_iterator<cpp11::tuple<V1>,cpp11::tuple<O1> >
 dispatch_or_drop_output(O1 out1){
-  return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1>,cpp0x::tuple<O1> >(out1);
+  return Dispatch_or_drop_output_iterator<cpp11::tuple<V1>,cpp11::tuple<O1> >(out1);
 }
 
 // Version with 2 parameters
 template<class V1,class O1,class V2,class O2>
-class Dispatch_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> >:public cpp0x::tuple<O1,O2>{
+class Dispatch_output_iterator<cpp11::tuple<V1,V2>,cpp11::tuple<O1,O2> >:public cpp11::tuple<O1,O2>{
   typedef Dispatch_output_iterator Self;
   
 public:
-  typedef cpp0x::tuple<V1,V2> Value_type_tuple;
-  typedef cpp0x::tuple<O1,O2> Iterator_tuple;
+  typedef cpp11::tuple<V1,V2> Value_type_tuple;
+  typedef cpp11::tuple<O1,O2> Iterator_tuple;
   typedef std::output_iterator_tag iterator_category;
   typedef void                     value_type;
   typedef void                     difference_type;
@@ -1455,12 +1458,12 @@ public:
   {}
 
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
@@ -1477,19 +1480,19 @@ public:
 
 template<class V1,class V2,class O1,class O2>
 inline 
-Dispatch_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> >
+Dispatch_output_iterator<cpp11::tuple<V1,V2>,cpp11::tuple<O1,O2> >
 dispatch_output(O1 out1,O2 out2){
-  return Dispatch_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> >(out1,out2);
+  return Dispatch_output_iterator<cpp11::tuple<V1,V2>,cpp11::tuple<O1,O2> >(out1,out2);
 }
 
 //Version with DROP
 
 template<class V1,class O1,class V2,class O2>
-class Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> >:
-        public Dispatch_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> >
+class Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2>,cpp11::tuple<O1,O2> >:
+        public Dispatch_output_iterator<cpp11::tuple<V1,V2>,cpp11::tuple<O1,O2> >
 {
   typedef Dispatch_or_drop_output_iterator Self;
-  typedef Dispatch_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> > Base;
+  typedef Dispatch_output_iterator<cpp11::tuple<V1,V2>,cpp11::tuple<O1,O2> > Base;
   
 public:
 
@@ -1500,15 +1503,15 @@ public:
   Dispatch_or_drop_output_iterator(O1 out1,O2 out2):Base(out1,out2){}
   
   #if defined(__EDG__)  
-  typedef cpp0x::tuple<O1,O2> Iterator_tuple;
+  typedef cpp11::tuple<O1,O2> Iterator_tuple;
     
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -1529,19 +1532,19 @@ public:
 
 template<class V1,class V2,class O1,class O2>
 inline 
-Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> >
+Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2>,cpp11::tuple<O1,O2> >
 dispatch_or_drop_output(O1 out1,O2 out2){
-  return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> >(out1,out2);
+  return Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2>,cpp11::tuple<O1,O2> >(out1,out2);
 }
 
 //Version with 3 parameters
 template<class V1,class O1,class V2,class O2,class V3, class O3>
-class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >:public cpp0x::tuple<O1,O2,O3>{
+class Dispatch_output_iterator<cpp11::tuple<V1,V2,V3>,cpp11::tuple<O1,O2,O3> >:public cpp11::tuple<O1,O2,O3>{
   typedef Dispatch_output_iterator Self;
   
 public:
-  typedef cpp0x::tuple<V1,V2,V3> Value_type_tuple;
-  typedef cpp0x::tuple<O1,O2,O3> Iterator_tuple;
+  typedef cpp11::tuple<V1,V2,V3> Value_type_tuple;
+  typedef cpp11::tuple<O1,O2,O3> Iterator_tuple;
   typedef std::output_iterator_tag iterator_category;
   typedef void                     value_type;
   typedef void                     difference_type;
@@ -1561,17 +1564,17 @@ public:
   {}  
 
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
 
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -1588,9 +1591,9 @@ public:
 
 template<class V1,class V2,class V3,class O1,class O2,class O3>
 inline 
-Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >
+Dispatch_output_iterator<cpp11::tuple<V1,V2,V3>,cpp11::tuple<O1,O2,O3> >
 dispatch_output(O1 out1,O2 out2,O3 out3){
-  return Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >(out1,out2,out3);
+  return Dispatch_output_iterator<cpp11::tuple<V1,V2,V3>,cpp11::tuple<O1,O2,O3> >(out1,out2,out3);
 }
 
 //Version with DROP
@@ -1599,11 +1602,11 @@ class Dispatch_or_drop_output_iterator;
 
 
 template<class V1,class O1,class V2,class O2,class V3,class O3>
-class Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >:
-        public Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >
+class Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3>,cpp11::tuple<O1,O2,O3> >:
+        public Dispatch_output_iterator<cpp11::tuple<V1,V2,V3>,cpp11::tuple<O1,O2,O3> >
 {
   typedef Dispatch_or_drop_output_iterator Self;
-  typedef Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> > Base;
+  typedef Dispatch_output_iterator<cpp11::tuple<V1,V2,V3>,cpp11::tuple<O1,O2,O3> > Base;
   
 public:
 
@@ -1614,20 +1617,20 @@ public:
   Dispatch_or_drop_output_iterator(O1 out1,O2 out2,O3 out3):Base(out1,out2,out3){}
   
   #if defined(__EDG__)  
-  typedef cpp0x::tuple<O1,O2,O3> Iterator_tuple;
+  typedef cpp11::tuple<O1,O2,O3> Iterator_tuple;
     
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -1648,19 +1651,19 @@ public:
 
 template<class V1,class V2,class V3,class O1,class O2,class O3>
 inline 
-Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >
+Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3>,cpp11::tuple<O1,O2,O3> >
 dispatch_or_drop_output(O1 out1,O2 out2,O3 out3){
-  return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >(out1,out2,out3);
+  return Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3>,cpp11::tuple<O1,O2,O3> >(out1,out2,out3);
 }
 
 //Version with 4 parameters
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4>
-class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >:public cpp0x::tuple<O1,O2,O3,O4>{
+class Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4>,cpp11::tuple<O1,O2,O3,O4> >:public cpp11::tuple<O1,O2,O3,O4>{
   typedef Dispatch_output_iterator Self;
   
 public:
-  typedef cpp0x::tuple<V1,V2,V3,V4> Value_type_tuple;
-  typedef cpp0x::tuple<O1,O2,O3,O4> Iterator_tuple;
+  typedef cpp11::tuple<V1,V2,V3,V4> Value_type_tuple;
+  typedef cpp11::tuple<O1,O2,O3,O4> Iterator_tuple;
   typedef std::output_iterator_tag iterator_category;
   typedef void                     value_type;
   typedef void                     difference_type;
@@ -1680,22 +1683,22 @@ public:
   {}  
   
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
 
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V4& obj){
-    *cpp0x::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -1712,9 +1715,9 @@ public:
 
 template<class V1,class V2,class V3,class V4,class O1,class O2,class O3,class O4>
 inline 
-Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >
+Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4>,cpp11::tuple<O1,O2,O3,O4> >
 dispatch_output(O1 out1,O2 out2,O3 out3,O4 out4){
-  return Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >(out1,out2,out3,out4);
+  return Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4>,cpp11::tuple<O1,O2,O3,O4> >(out1,out2,out3,out4);
 }
 
 //Version with DROP
@@ -1723,11 +1726,11 @@ class Dispatch_or_drop_output_iterator;
 
 
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4>
-class Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >:
-        public Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >
+class Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4>,cpp11::tuple<O1,O2,O3,O4> >:
+        public Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4>,cpp11::tuple<O1,O2,O3,O4> >
 {
   typedef Dispatch_or_drop_output_iterator Self;
-  typedef Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> > Base;
+  typedef Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4>,cpp11::tuple<O1,O2,O3,O4> > Base;
   
 public:
 
@@ -1738,25 +1741,25 @@ public:
   Dispatch_or_drop_output_iterator(O1 out1,O2 out2,O3 out3,O4 out4):Base(out1,out2,out3,out4){}
   
   #if defined(__EDG__)  
-  typedef cpp0x::tuple<O1,O2,O3,O4> Iterator_tuple;
+  typedef cpp11::tuple<O1,O2,O3,O4> Iterator_tuple;
     
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V4& obj){
-    *cpp0x::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -1777,19 +1780,19 @@ public:
 
 template<class V1,class V2,class V3,class V4,class O1,class O2,class O3,class O4>
 inline 
-Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >
+Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4>,cpp11::tuple<O1,O2,O3,O4> >
 dispatch_or_drop_output(O1 out1,O2 out2,O3 out3,O4 out4){
-  return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >(out1,out2,out3,out4);
+  return Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4>,cpp11::tuple<O1,O2,O3,O4> >(out1,out2,out3,out4);
 }
 
 //Version with 5 parameters
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5>
-class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >:public cpp0x::tuple<O1,O2,O3,O4,O5>{
+class Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5>,cpp11::tuple<O1,O2,O3,O4,O5> >:public cpp11::tuple<O1,O2,O3,O4,O5>{
   typedef Dispatch_output_iterator Self;
   
 public:
-  typedef cpp0x::tuple<V1,V2,V3,V4,V5> Value_type_tuple;
-  typedef cpp0x::tuple<O1,O2,O3,O4,O5> Iterator_tuple;
+  typedef cpp11::tuple<V1,V2,V3,V4,V5> Value_type_tuple;
+  typedef cpp11::tuple<O1,O2,O3,O4,O5> Iterator_tuple;
   typedef std::output_iterator_tag iterator_category;
   typedef void                     value_type;
   typedef void                     difference_type;
@@ -1809,27 +1812,27 @@ public:
   {}  
   
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
 
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V4& obj){
-    *cpp0x::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V5& obj){
-    *cpp0x::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -1846,9 +1849,9 @@ public:
 
 template<class V1,class V2,class V3,class V4,class V5,class O1,class O2,class O3,class O4,class O5>
 inline 
-Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >
+Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5>,cpp11::tuple<O1,O2,O3,O4,O5> >
 dispatch_output(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5){
-  return Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >(out1,out2,out3,out4,out5);
+  return Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5>,cpp11::tuple<O1,O2,O3,O4,O5> >(out1,out2,out3,out4,out5);
 }
 
 //Version with DROP
@@ -1857,11 +1860,11 @@ class Dispatch_or_drop_output_iterator;
 
 
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5>
-class Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >:
-        public Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >
+class Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5>,cpp11::tuple<O1,O2,O3,O4,O5> >:
+        public Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5>,cpp11::tuple<O1,O2,O3,O4,O5> >
 {
   typedef Dispatch_or_drop_output_iterator Self;
-  typedef Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> > Base;
+  typedef Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5>,cpp11::tuple<O1,O2,O3,O4,O5> > Base;
   
 public:
 
@@ -1872,30 +1875,30 @@ public:
   Dispatch_or_drop_output_iterator(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5):Base(out1,out2,out3,out4,out5){}
   
   #if defined(__EDG__)  
-  typedef cpp0x::tuple<O1,O2,O3,O4,O5> Iterator_tuple;
+  typedef cpp11::tuple<O1,O2,O3,O4,O5> Iterator_tuple;
     
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V4& obj){
-    *cpp0x::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V5& obj){
-    *cpp0x::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -1916,19 +1919,19 @@ public:
 
 template<class V1,class V2,class V3,class V4,class V5,class O1,class O2,class O3,class O4,class O5>
 inline 
-Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >
+Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5>,cpp11::tuple<O1,O2,O3,O4,O5> >
 dispatch_or_drop_output(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5){
-  return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >(out1,out2,out3,out4,out5);
+  return Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5>,cpp11::tuple<O1,O2,O3,O4,O5> >(out1,out2,out3,out4,out5);
 }
 
 //Version with 6 parameters
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5,class V6,class O6>
-class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >:public cpp0x::tuple<O1,O2,O3,O4,O5,O6>{
+class Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6>,cpp11::tuple<O1,O2,O3,O4,O5,O6> >:public cpp11::tuple<O1,O2,O3,O4,O5,O6>{
   typedef Dispatch_output_iterator Self;
   
 public:
-  typedef cpp0x::tuple<V1,V2,V3,V4,V5,V6> Value_type_tuple;
-  typedef cpp0x::tuple<O1,O2,O3,O4,O5,O6> Iterator_tuple;
+  typedef cpp11::tuple<V1,V2,V3,V4,V5,V6> Value_type_tuple;
+  typedef cpp11::tuple<O1,O2,O3,O4,O5,O6> Iterator_tuple;
   typedef std::output_iterator_tag iterator_category;
   typedef void                     value_type;
   typedef void                     difference_type;
@@ -1948,32 +1951,32 @@ public:
   {}  
   
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
 
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V4& obj){
-    *cpp0x::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V5& obj){
-    *cpp0x::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V6& obj){
-    *cpp0x::get<5>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<5>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -1990,9 +1993,9 @@ public:
 
 template<class V1,class V2,class V3,class V4,class V5,class V6,class O1,class O2,class O3,class O4,class O5,class O6>
 inline 
-Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >
+Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6>,cpp11::tuple<O1,O2,O3,O4,O5,O6> >
 dispatch_output(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6){
-  return Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >(out1,out2,out3,out4,out5,out6);
+  return Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6>,cpp11::tuple<O1,O2,O3,O4,O5,O6> >(out1,out2,out3,out4,out5,out6);
 }
 
 //Version with DROP
@@ -2001,11 +2004,11 @@ class Dispatch_or_drop_output_iterator;
 
 
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5,class V6,class O6>
-class Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >:
-        public Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >
+class Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6>,cpp11::tuple<O1,O2,O3,O4,O5,O6> >:
+        public Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6>,cpp11::tuple<O1,O2,O3,O4,O5,O6> >
 {
   typedef Dispatch_or_drop_output_iterator Self;
-  typedef Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> > Base;
+  typedef Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6>,cpp11::tuple<O1,O2,O3,O4,O5,O6> > Base;
   
 public:
 
@@ -2016,35 +2019,35 @@ public:
   Dispatch_or_drop_output_iterator(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6):Base(out1,out2,out3,out4,out5,out6){}
   
   #if defined(__EDG__)  
-  typedef cpp0x::tuple<O1,O2,O3,O4,O5,O6> Iterator_tuple;
+  typedef cpp11::tuple<O1,O2,O3,O4,O5,O6> Iterator_tuple;
     
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V4& obj){
-    *cpp0x::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V5& obj){
-    *cpp0x::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V6& obj){
-    *cpp0x::get<5>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<5>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -2065,19 +2068,19 @@ public:
 
 template<class V1,class V2,class V3,class V4,class V5,class V6,class O1,class O2,class O3,class O4,class O5,class O6>
 inline 
-Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >
+Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6>,cpp11::tuple<O1,O2,O3,O4,O5,O6> >
 dispatch_or_drop_output(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6){
-  return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >(out1,out2,out3,out4,out5,out6);
+  return Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6>,cpp11::tuple<O1,O2,O3,O4,O5,O6> >(out1,out2,out3,out4,out5,out6);
 }
 
 //Version with 7 parameters
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5,class V6,class O6,class V7,class O7>
-class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> >:public cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7>{
+class Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> >:public cpp11::tuple<O1,O2,O3,O4,O5,O6,O7>{
   typedef Dispatch_output_iterator Self;
   
 public:
-  typedef cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7> Value_type_tuple;
-  typedef cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> Iterator_tuple;
+  typedef cpp11::tuple<V1,V2,V3,V4,V5,V6,V7> Value_type_tuple;
+  typedef cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> Iterator_tuple;
   typedef std::output_iterator_tag iterator_category;
   typedef void                     value_type;
   typedef void                     difference_type;
@@ -2097,37 +2100,37 @@ public:
   {}  
   
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
 
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V4& obj){
-    *cpp0x::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V5& obj){
-    *cpp0x::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V6& obj){
-    *cpp0x::get<5>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<5>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
    Self& operator=(const V7& obj){
-    *cpp0x::get<6>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<6>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -2144,9 +2147,9 @@ public:
 
 template<class V1,class V2,class V3,class V4,class V5,class V6,class V7,class O1,class O2,class O3,class O4,class O5,class O6,class O7>
 inline 
-Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> >
+Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> >
 dispatch_output(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6,O7 out7){
-  return Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> >(out1,out2,out3,out4,out5,out6,out7);
+  return Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> >(out1,out2,out3,out4,out5,out6,out7);
 }
 
 //Version with DROP
@@ -2155,11 +2158,11 @@ class Dispatch_or_drop_output_iterator;
 
 
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5,class V6,class O6,class V7,class O7>
-class Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> >:
-        public Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> >
+class Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> >:
+        public Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> >
 {
   typedef Dispatch_or_drop_output_iterator Self;
-  typedef Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> > Base;
+  typedef Dispatch_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> > Base;
   
 public:
 
@@ -2170,40 +2173,40 @@ public:
   Dispatch_or_drop_output_iterator(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6,O7 out7):Base(out1,out2,out3,out4,out5,out6,out7){}
   
   #if defined(__EDG__)  
-  typedef cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> Iterator_tuple;
+  typedef cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> Iterator_tuple;
     
   Self& operator=(const V1& obj){
-    *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }
   
   Self& operator=(const V2& obj){
-    *cpp0x::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<1>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V3& obj){
-    *cpp0x::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<2>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V4& obj){
-    *cpp0x::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<3>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V5& obj){
-    *cpp0x::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<4>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
   Self& operator=(const V6& obj){
-    *cpp0x::get<5>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<5>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
 
   Self& operator=(const V7& obj){
-    *cpp0x::get<6>(static_cast<Iterator_tuple& >(*this))++=obj;
+    *cpp11::get<6>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
   }  
   
@@ -2224,9 +2227,9 @@ public:
 
 template<class V1,class V2,class V3,class V4,class V5,class V6,class V7,class O1,class O2,class O3,class O4,class O5,class O6,class O7>
 inline 
-Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> >
+Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> >
 dispatch_or_drop_output(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6,O7 out7){
-  return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> >(out1,out2,out3,out4,out5,out6,out7);
+  return Dispatch_or_drop_output_iterator<cpp11::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp11::tuple<O1,O2,O3,O4,O5,O6,O7> >(out1,out2,out3,out4,out5,out6,out7);
 }
 
 #endif
