@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Point_set_processing_3/include/CGAL/mst_orient_normals.h $
-// $Id: mst_orient_normals.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 //
 // Author(s) : Laurent Saboret and Andreas Fabri
 
@@ -28,6 +28,7 @@
 #include <CGAL/Index_property_map.h>
 #include <CGAL/Memory_sizer.h>
 #include <CGAL/point_set_processing_assertions.h>
+#include <CGAL/use.h>
 
 #include <iterator>
 #include <list>
@@ -50,10 +51,10 @@ namespace CGAL {
 // Private section
 // ----------------------------------------------------------------------------
 namespace internal {
-
+/// \cond SKIP_IN_MANUAL
 
 /// Generalization of std::distance() to compute the distance between 2 integers
-inline int
+inline std::size_t
 distance(std::size_t _First, std::size_t _Last)
 {
   // return int difference
@@ -125,14 +126,12 @@ public:
 /// It does not orient normals that are already oriented.
 /// It does not propagate the orientation if the angle between 2 normals > angle_max.
 ///
-/// @commentheading Preconditions:
-/// - Normals must be unit vectors.
-/// - 0 < angle_max <= PI/2.
+/// \pre Normals must be unit vectors
+/// \pre `0 < angle_max <= PI/2`
 ///
-/// @commentheading Template Parameters:
-/// @param ForwardIterator iterator over input points.
-/// @param NormalPMap is a model of boost::ReadWritePropertyMap.
-/// @param Kernel Geometric traits class.
+/// @tparam ForwardIterator iterator over input points.
+/// @tparam NormalPMap is a model of `ReadWritePropertyMap`.
+/// @tparam Kernel Geometric traits class.
 
 template <typename ForwardIterator, ///< Input point iterator
           typename NormalPMap, ///< property map ForwardIterator -> Normal
@@ -190,11 +189,10 @@ private:
 
 /// Orients the normal of the point with maximum Z towards +Z axis.
 ///
-/// @commentheading Template Parameters:
-/// @param ForwardIterator iterator over input points.
-/// @param PointPMap is a model of boost::ReadablePropertyMap with a value_type = Point_3<Kernel>.
-/// @param NormalPMap is a model of boost::ReadWritePropertyMap with a value_type = Vector_3<Kernel>.
-/// @param Kernel Geometric traits class.
+/// @tparam ForwardIterator iterator over input points.
+/// @tparam PointPMap is a model of `ReadablePropertyMap` with a value_type = Point_3<Kernel>.
+/// @tparam NormalPMap is a model of `ReadWritePropertyMap` with a value_type = Vector_3<Kernel>.
+/// @tparam Kernel Geometric traits class.
 ///
 /// @return iterator over the top point.
 template <typename ForwardIterator,
@@ -208,7 +206,7 @@ mst_find_source(
     ForwardIterator beyond,  ///< past-the-end iterator over the input points.
     PointPMap point_pmap, ///< property map ForwardIterator -> Point_3
     NormalPMap normal_pmap, ///< property map ForwardIterator -> Vector_3
-    const Kernel& kernel)    ///< geometric traits.
+    const Kernel& /*kernel*/)    ///< geometric traits.
 {
     CGAL_TRACE("  mst_find_source()\n");
 
@@ -245,16 +243,14 @@ mst_find_source(
 /// - we add the edge (i, j) if either vertex i is in the k-neighborhood of vertex j,
 ///   or vertex j is in the k-neighborhood of vertex i.
 ///
-/// @commentheading Preconditions:
-/// - Normals must be unit vectors.
-/// - k >= 2.
+/// \pre Normals must be unit vectors.
+/// \pre `k >= 2`
 ///
-/// @commentheading Template Parameters:
-/// @param ForwardIterator iterator over input points.
-/// @param IndexPMap is a model of boost::ReadablePropertyMap with an integral value_type.
-/// @param PointPMap is a model of boost::ReadablePropertyMap with a value_type = Point_3<Kernel>.
-/// @param NormalPMap is a model of boost::ReadWritePropertyMap with a value_type = Vector_3<Kernel>.
-/// @param Kernel Geometric traits class.
+/// @tparam ForwardIterator iterator over input points.
+/// @tparam IndexPMap is a model of `ReadablePropertyMap` with an integral value_type.
+/// @tparam PointPMap is a model of `ReadablePropertyMap` with a value_type = Point_3<Kernel>.
+/// @tparam NormalPMap is a model of `ReadWritePropertyMap` with a value_type = Vector_3<Kernel>.
+/// @tparam Kernel Geometric traits class.
 ///
 /// @return the Riemannian graph
 template <typename ForwardIterator,
@@ -271,7 +267,7 @@ create_riemannian_graph(
     NormalPMap normal_pmap, ///< property map ForwardIterator -> Vector_3
     IndexPMap index_pmap, ///< property map ForwardIterator -> index
     unsigned int k, ///< number of neighbors
-    const Kernel& kernel) ///< geometric traits.
+    const Kernel& /*kernel*/) ///< geometric traits.
 {
     // Input points types
     typedef typename boost::property_traits<PointPMap>::value_type Point;
@@ -296,9 +292,9 @@ create_riemannian_graph(
     CGAL_point_set_processing_precondition(k >= 2);
 
     // Number of input points
-    const int num_input_points = distance(first, beyond);
+    const std::size_t num_input_points = distance(first, beyond);
 
-    long memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
+    std::size_t memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
     CGAL_TRACE("  Creates KD-tree\n");
 
     // Instanciate a KD-tree search.
@@ -316,7 +312,7 @@ create_riemannian_graph(
     // Recover RAM
     kd_tree_points.clear();
 
-    /*long*/ memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
+    memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
     CGAL_TRACE("  Creates Riemannian Graph\n");
 
     // Iterates over input points and creates Riemannian Graph:
@@ -338,7 +334,7 @@ create_riemannian_graph(
     Riemannian_graph_weight_map riemannian_graph_weight_map = get(boost::edge_weight, riemannian_graph);
     for (ForwardIterator it = first; it != beyond; it++)
     {
-        unsigned int it_index = get(index_pmap,it);
+        std::size_t it_index = get(index_pmap,it);
         Vector it_normal_vector = get(normal_pmap,it);
 
         // Gather set of (k+1) neighboring points.
@@ -349,13 +345,13 @@ create_riemannian_graph(
         Point_vertex_handle_3 point_wrapper(point.x(), point.y(), point.z(), it);
         Neighbor_search search(*tree, point_wrapper, k+1);
         Search_iterator search_iterator = search.begin();
-        for(unsigned int i=0;i<(k+1);i++)
+        for(std::size_t i=0;i<(k+1);i++)
         {
             if(search_iterator == search.end())
                 break; // premature ending
 
             ForwardIterator neighbor = search_iterator->first;
-            unsigned int neighbor_index = get(index_pmap,neighbor);
+            std::size_t neighbor_index = get(index_pmap,neighbor);
             if (neighbor_index > it_index) // undirected graph
             {
                 // Add edge
@@ -388,15 +384,13 @@ create_riemannian_graph(
 /// - vertices contain the corresponding input point iterator.
 /// - we add the edge (predecessor[i], i) for each element of the MST.
 ///
-/// @commentheading Preconditions:
-/// - Normals must be unit vectors.
+/// \pre Normals must be unit vectors.
 ///
-/// @commentheading Template Parameters:
-/// @param ForwardIterator iterator over input points.
-/// @param IndexPMap is a model of boost::ReadablePropertyMap with an integral value_type.
-/// @param PointPMap is a model of boost::ReadablePropertyMap with a value_type = Point_3<Kernel>.
-/// @param NormalPMap is a model of boost::ReadWritePropertyMap with a value_type = Vector_3<Kernel>.
-/// @param Kernel Geometric traits class.
+/// @tparam ForwardIterator iterator over input points.
+/// @tparam IndexPMap is a model of `ReadablePropertyMap` with an integral value_type.
+/// @tparam PointPMap is a model of `ReadablePropertyMap` with a value_type = Point_3<Kernel>.
+/// @tparam NormalPMap is a model of `ReadWritePropertyMap` with a value_type = Vector_3<Kernel>.
+/// @tparam Kernel Geometric traits class.
 ///
 /// @return the MST graph.
 template <typename ForwardIterator,
@@ -417,13 +411,14 @@ create_mst_graph(
     const Riemannian_graph<ForwardIterator>& riemannian_graph, ///< graph connecting each vertex to its knn
     ForwardIterator source_point) ///< source point (with an oriented normal)
 {
+    // prevents warnings
+    CGAL_USE(point_pmap);
+    CGAL_USE(k);
+    CGAL_USE(kernel);
+
     // Bring private stuff to scope
     using namespace internal;
 
-    // Input points types
-    typedef typename boost::property_traits<PointPMap>::value_type Point;
-    typedef typename boost::property_traits<NormalPMap>::value_type Vector;
-
     // Riemannian_graph types
     typedef internal::Riemannian_graph<ForwardIterator> Riemannian_graph;
     typedef typename boost::property_map<Riemannian_graph, boost::edge_weight_t>::const_type Riemannian_graph_weight_map;
@@ -435,13 +430,13 @@ create_mst_graph(
     CGAL_point_set_processing_precondition(first != beyond);
 
     // Number of input points
-    const int num_input_points = boost::num_vertices(riemannian_graph);
+    const std::size_t num_input_points = boost::num_vertices(riemannian_graph);
 
-    long memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
+    std::size_t memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
     CGAL_TRACE("  Calls boost::prim_minimum_spanning_tree()\n");
 
     // Computes Minimum Spanning Tree.
-    unsigned int source_point_index = get(index_pmap, source_point);
+    std::size_t source_point_index = get(index_pmap, source_point);
     Riemannian_graph_weight_map riemannian_graph_weight_map = get(boost::edge_weight, riemannian_graph);
     typedef std::vector<typename Riemannian_graph::vertex_descriptor> PredecessorMap;
     PredecessorMap predecessor(num_input_points);
@@ -449,7 +444,7 @@ create_mst_graph(
                                       weight_map( riemannian_graph_weight_map )
                                      .root_vertex( boost::vertex(source_point_index, riemannian_graph) ));
 
-    /*long*/ memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
+    memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
     CGAL_TRACE("  Creates MST Graph\n");
 
     // Converts predecessor map to a MST graph:
@@ -467,7 +462,7 @@ create_mst_graph(
         mst_graph[v].is_oriented = (it == source_point);
     }
     // add edges
-    for (unsigned int i=0; i < predecessor.size(); i++) // add edges
+    for (std::size_t i=0; i < predecessor.size(); i++) // add edges
     {
         if (i != predecessor[i])
         {
@@ -483,6 +478,7 @@ create_mst_graph(
     return mst_graph;
 }
 
+/// \endcond
 
 } /* namespace internal */
 
@@ -491,24 +487,22 @@ create_mst_graph(
 // Public section
 // ----------------------------------------------------------------------------
 
-
-/// Orients the normals of the [first, beyond) range of points using the propagation
+/// \ingroup PkgPointSetProcessing
+/// Orients the normals of the `[first, beyond)` range of points using the propagation
 /// of a seed orientation through a minimum spanning tree of the Riemannian graph [Hoppe92].
 ///
 /// This method modifies the order of input points so as to pack all sucessfully oriented points first,
 /// and returns an iterator over the first point with an unoriented normal (see erase-remove idiom).
 /// For this reason it should not be called on sorted containers.
 ///
-/// @commentheading Preconditions:
-/// - Normals must be unit vectors.
-/// - k >= 2.
+/// \pre Normals must be unit vectors
+/// \pre `k >= 2`
 ///
-/// @commentheading Template Parameters:
-/// @param ForwardIterator iterator over input points.
-/// @param PointPMap is a model of boost::ReadablePropertyMap with a value_type = Point_3<Kernel>.
+/// @tparam ForwardIterator iterator over input points.
+/// @tparam PointPMap is a model of `ReadablePropertyMap` with a value_type = Point_3<Kernel>.
 ///        It can be omitted if ForwardIterator value_type is convertible to Point_3<Kernel>.
-/// @param NormalPMap is a model of boost::ReadWritePropertyMap with a value_type = Vector_3<Kernel>.
-/// @param Kernel Geometric traits class.
+/// @tparam NormalPMap is a model of `ReadWritePropertyMap` with a value_type = Vector_3<Kernel>.
+/// @tparam Kernel Geometric traits class.
 ///        It can be omitted and deduced automatically from PointPMap value_type.
 ///
 /// @return iterator over the first point with an unoriented normal.
@@ -535,8 +529,6 @@ mst_orient_normals(
 
     // Input points types
     typedef typename std::iterator_traits<ForwardIterator>::value_type Enriched_point; // actual type of input points
-    typedef typename boost::property_traits<NormalPMap>::value_type Vector;
-
     // Property map ForwardIterator -> index
     typedef Index_property_map<ForwardIterator> IndexPMap;
 
@@ -552,7 +544,7 @@ mst_orient_normals(
     // Precondition: at least 2 nearest neighbors
     CGAL_point_set_processing_precondition(k >= 2);
 
-    long memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
+    std::size_t memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
     CGAL_TRACE("  Create Index_property_map\n");
 
     // Create a property map Iterator -> index.
@@ -587,12 +579,12 @@ mst_orient_normals(
                                            riemannian_graph,
                                            source_point);
 
-    /*long*/ memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
+    memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
     CGAL_TRACE("  Calls boost::breadth_first_search()\n");
 
     // Traverse the point set along the MST to propagate source_point's orientation
     Propagate_normal_orientation<ForwardIterator, NormalPMap, Kernel> orienter;
-    unsigned int source_point_index = get(index_pmap, source_point);
+    std::size_t source_point_index = get(index_pmap, source_point);
     boost::breadth_first_search(mst_graph,
                                 boost::vertex(source_point_index, mst_graph), // source
                                 visitor(boost::make_bfs_visitor(orienter)));
@@ -601,7 +593,7 @@ mst_orient_normals(
     std::deque<Enriched_point> oriented_points, unoriented_points;
     for (ForwardIterator it = first; it != beyond; it++)
     {
-        unsigned int it_index = get(index_pmap,it);
+        std::size_t it_index = get(index_pmap,it);
         typename MST_graph::vertex_descriptor v = boost::vertex(it_index, mst_graph);
         if (mst_graph[v].is_oriented)
           oriented_points.push_back(*it);
@@ -617,7 +609,7 @@ mst_orient_normals(
     // At this stage, we have typically 0 unoriented normals if k is large enough
     CGAL_TRACE("  => %u normals are unoriented\n", unoriented_points.size());
 
-    /*long*/ memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
+    memory = CGAL::Memory_sizer().virtual_size(); CGAL_TRACE("  %ld Mb allocated\n", memory>>20);
     CGAL_TRACE("End of mst_orient_normals()\n");
 
     return first_unoriented_point;
