@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/releases/CGAL-4.0-branch/Matrix_search/include/CGAL/rectangular_3_center_2.h $
-// $Id: rectangular_3_center_2.h 67117 2012-01-13 18:14:48Z lrineau $
+// $URL$
+// $Id$
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
@@ -865,7 +865,6 @@ rectangular_3_center_2_type2(
   using std::pair;
 
   typedef typename Operations::Point                       Point;
-  typedef typename Operations::Distance                 Distance;
   typedef pair< RandomAccessIterator, RandomAccessIterator >  IP;
 
   typename Operations::Construct_iso_rectangle_2
@@ -926,7 +925,7 @@ rectangular_3_center_2_type2(
 #ifndef CGAL_3COVER_NO_PREFILTER
   // Prefiltering heuristic
   while (e - s > 6) {
-    int cutoff = (e - s) / 2;
+    std::ptrdiff_t cutoff = (e - s) / 2;
     RandomAccessIterator m = s + cutoff - 1;
     nth_element(s, m, e, 
 		boost::bind(less<FT>(), boost::bind(op.delta(), _1), boost::bind(op.delta(), _2)));
@@ -964,7 +963,7 @@ rectangular_3_center_2_type2(
          << ")" << endl;
     */
     // step (a)
-    int cutoff = (e - s) / fraction;
+    std::ptrdiff_t cutoff = (e - s) / fraction;
     RandomAccessIterator m = s + cutoff - 1;
     nth_element(s, m, e, 
 		boost::bind(less<FT>(), boost::bind(op.delta(), _1), boost::bind(op.delta(), _2)));
@@ -1136,7 +1135,8 @@ rectangular_3_center_2_type2(
 
     // now s_b corresponds to the first moment in [s, m+1)
     // where q_t and q_r cover B
-
+    CGAL_optimisation_assertion_code(bool loopcheck = false;)
+CGAL_3CENTER_REPEAT_CHECK:
     // place q_t and q_r
     q_t = op.place_x_square(q_t_afap, r, op.delta()(*s_b));
     q_r = op.place_y_square(q_r_afap, r, op.delta()(*s_b));
@@ -1157,7 +1157,15 @@ rectangular_3_center_2_type2(
         (!Q_t_empty && op.compute_x_distance(q_t, Q_t) > op.delta()(*s_b)) ||
         (!Q_r_empty && op.compute_y_distance(q_r, Q_r) > op.delta()(*s_b))) {
       // no covering
-      CGAL_optimisation_assertion(b1 - s >= cutoff);
+      if (b1 - s < cutoff) {
+	// in degenerate situations it can happen that the number of
+	// points in R is too small => decrease radius and check again
+	--s_b;
+	CGAL_optimisation_assertion(!loopcheck);
+	CGAL_optimisation_assertion(s != s_b);
+	CGAL_optimisation_assertion_code(loopcheck = true;)
+	goto CGAL_3CENTER_REPEAT_CHECK;
+      }
       s = b1;
       rho_min = op.delta()(*s_b);
       q_t_at_rho_min = q_t, q_r_at_rho_min = q_r;
